/*
 * This file was generated automatically by ExtUtils::ParseXS version 3.51 from the
 * contents of SQLite.xs. Do not edit this file, edit SQLite.xs instead.
 *
 *    ANY CHANGES MADE HERE WILL BE LOST!
 *
 */

#line 1 "SQLite.xs"
#define PERL_NO_GET_CONTEXT

#include "SQLiteXS.h"

DBISTATE_DECLARE;

#line 17 "SQLite.c"
#ifndef PERL_UNUSED_VAR
#  define PERL_UNUSED_VAR(var) if (0) var = var
#endif

#ifndef dVAR
#  define dVAR		dNOOP
#endif


/* This stuff is not part of the API! You have been warned. */
#ifndef PERL_VERSION_DECIMAL
#  define PERL_VERSION_DECIMAL(r,v,s) (r*1000000 + v*1000 + s)
#endif
#ifndef PERL_DECIMAL_VERSION
#  define PERL_DECIMAL_VERSION \
	  PERL_VERSION_DECIMAL(PERL_REVISION,PERL_VERSION,PERL_SUBVERSION)
#endif
#ifndef PERL_VERSION_GE
#  define PERL_VERSION_GE(r,v,s) \
	  (PERL_DECIMAL_VERSION >= PERL_VERSION_DECIMAL(r,v,s))
#endif
#ifndef PERL_VERSION_LE
#  define PERL_VERSION_LE(r,v,s) \
	  (PERL_DECIMAL_VERSION <= PERL_VERSION_DECIMAL(r,v,s))
#endif

/* XS_INTERNAL is the explicit static-linkage variant of the default
 * XS macro.
 *
 * XS_EXTERNAL is the same as XS_INTERNAL except it does not include
 * "STATIC", ie. it exports XSUB symbols. You probably don't want that
 * for anything but the BOOT XSUB.
 *
 * See XSUB.h in core!
 */


/* TODO: This might be compatible further back than 5.10.0. */
#if PERL_VERSION_GE(5, 10, 0) && PERL_VERSION_LE(5, 15, 1)
#  undef XS_EXTERNAL
#  undef XS_INTERNAL
#  if defined(__CYGWIN__) && defined(USE_DYNAMIC_LOADING)
#    define XS_EXTERNAL(name) __declspec(dllexport) XSPROTO(name)
#    define XS_INTERNAL(name) STATIC XSPROTO(name)
#  endif
#  if defined(__SYMBIAN32__)
#    define XS_EXTERNAL(name) EXPORT_C XSPROTO(name)
#    define XS_INTERNAL(name) EXPORT_C STATIC XSPROTO(name)
#  endif
#  ifndef XS_EXTERNAL
#    if defined(HASATTRIBUTE_UNUSED) && !defined(__cplusplus)
#      define XS_EXTERNAL(name) void name(pTHX_ CV* cv __attribute__unused__)
#      define XS_INTERNAL(name) STATIC void name(pTHX_ CV* cv __attribute__unused__)
#    else
#      ifdef __cplusplus
#        define XS_EXTERNAL(name) extern "C" XSPROTO(name)
#        define XS_INTERNAL(name) static XSPROTO(name)
#      else
#        define XS_EXTERNAL(name) XSPROTO(name)
#        define XS_INTERNAL(name) STATIC XSPROTO(name)
#      endif
#    endif
#  endif
#endif

/* perl >= 5.10.0 && perl <= 5.15.1 */


/* The XS_EXTERNAL macro is used for functions that must not be static
 * like the boot XSUB of a module. If perl didn't have an XS_EXTERNAL
 * macro defined, the best we can do is assume XS is the same.
 * Dito for XS_INTERNAL.
 */
#ifndef XS_EXTERNAL
#  define XS_EXTERNAL(name) XS(name)
#endif
#ifndef XS_INTERNAL
#  define XS_INTERNAL(name) XS(name)
#endif

/* Now, finally, after all this mess, we want an ExtUtils::ParseXS
 * internal macro that we're free to redefine for varying linkage due
 * to the EXPORT_XSUB_SYMBOLS XS keyword. This is internal, use
 * XS_EXTERNAL(name) or XS_INTERNAL(name) in your code if you need to!
 */

#undef XS_EUPXS
#if defined(PERL_EUPXS_ALWAYS_EXPORT)
#  define XS_EUPXS(name) XS_EXTERNAL(name)
#else
   /* default to internal */
#  define XS_EUPXS(name) XS_INTERNAL(name)
#endif

#ifndef PERL_ARGS_ASSERT_CROAK_XS_USAGE
#define PERL_ARGS_ASSERT_CROAK_XS_USAGE assert(cv); assert(params)

/* prototype to pass -Wmissing-prototypes */
STATIC void
S_croak_xs_usage(const CV *const cv, const char *const params);

STATIC void
S_croak_xs_usage(const CV *const cv, const char *const params)
{
    const GV *const gv = CvGV(cv);

    PERL_ARGS_ASSERT_CROAK_XS_USAGE;

    if (gv) {
        const char *const gvname = GvNAME(gv);
        const HV *const stash = GvSTASH(gv);
        const char *const hvname = stash ? HvNAME(stash) : NULL;

        if (hvname)
	    Perl_croak_nocontext("Usage: %s::%s(%s)", hvname, gvname, params);
        else
	    Perl_croak_nocontext("Usage: %s(%s)", gvname, params);
    } else {
        /* Pants. I don't think that it should be possible to get here. */
	Perl_croak_nocontext("Usage: CODE(0x%" UVxf ")(%s)", PTR2UV(cv), params);
    }
}
#undef  PERL_ARGS_ASSERT_CROAK_XS_USAGE

#define croak_xs_usage        S_croak_xs_usage

#endif

/* NOTE: the prototype of newXSproto() is different in versions of perls,
 * so we define a portable version of newXSproto()
 */
#ifdef newXS_flags
#define newXSproto_portable(name, c_impl, file, proto) newXS_flags(name, c_impl, file, proto, 0)
#else
#define newXSproto_portable(name, c_impl, file, proto) (PL_Sv=(SV*)newXS(name, c_impl, file), sv_setpv(PL_Sv, proto), (CV*)PL_Sv)
#endif /* !defined(newXS_flags) */

#if PERL_VERSION_LE(5, 21, 5)
#  define newXS_deffile(a,b) Perl_newXS(aTHX_ a,b,file)
#else
#  define newXS_deffile(a,b) Perl_newXS_deffile(aTHX_ a,b)
#endif

#line 161 "SQLite.c"

XS_EUPXS(XS_DBD__SQLite__db__do); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db__do)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "dbh, statement");
    {
	SV *	dbh = ST(0)
;
	SV *	statement = ST(1)
;
#line 21 "SQLite.xs"
    {
        D_imp_dbh(dbh);
        IV retval;
        retval = sqlite_db_do_sv(dbh, imp_dbh, statement);
        /* remember that dbd_db_do_sv must return <= -2 for error     */
        if (retval == 0)            /* ok with no rows affected     */
            XST_mPV(0, "0E0");      /* (true but zero)              */
        else if (retval < -1)       /* -1 == unknown number of rows */
            XST_mUNDEF(0);          /* <= -2 means error            */
        else
            XST_mIV(0, retval);     /* typically 1, rowcount or -1  */
    }
#line 187 "SQLite.c"
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__db_last_insert_rowid); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_last_insert_rowid)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 1)
       croak_xs_usage(cv,  "dbh");
    {
	SV *	dbh = ST(0)
;
	IV	RETVAL;
	dXSTARG;
#line 40 "SQLite.xs"
    {
        D_imp_dbh(dbh);
        RETVAL = (IV)sqlite3_last_insert_rowid(imp_dbh->db);
    }
#line 210 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__db_create_function); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_create_function)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items < 4 || items > 5)
       croak_xs_usage(cv,  "dbh, name, argc, func, flags = 0");
    {
	SV *	dbh = ST(0)
;
	char *	name = (char *)SvPV_nolen(ST(1))
;
	int	argc = (int)SvIV(ST(2))
;
	SV *	func = ST(3)
;
	int	flags;
	int	RETVAL;
	dXSTARG;

	if (items < 5)
	    flags = 0;
	else {
	    flags = (int)SvIV(ST(4))
;
	}
#line 57 "SQLite.xs"
    {
        RETVAL = sqlite_db_create_function(aTHX_ dbh, name, argc, func, flags );
    }
#line 248 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#ifndef SQLITE_OMIT_LOAD_EXTENSION
#define XSubPPtmpAAAA 1


XS_EUPXS(XS_DBD__SQLite__db_enable_load_extension); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_enable_load_extension)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 2)
       croak_xs_usage(cv,  "dbh, onoff");
    {
	SV *	dbh = ST(0)
;
	int	onoff = (int)SvIV(ST(1))
;
	int	RETVAL;
	dXSTARG;
#line 72 "SQLite.xs"
    {
        RETVAL = sqlite_db_enable_load_extension(aTHX_ dbh, onoff );
    }
#line 277 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__db_load_extension); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_load_extension)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "dbh, file, proc = 0");
    {
	SV *	dbh = ST(0)
;
	const char *	file = (const char *)SvPV_nolen(ST(1))
;
	const char *	proc;
	int	RETVAL;
	dXSTARG;

	if (items < 3)
	    proc = 0;
	else {
	    proc = (const char *)SvPV_nolen(ST(2))
;
	}
#line 86 "SQLite.xs"
    {
        RETVAL = sqlite_db_load_extension(aTHX_ dbh, file, proc);
    }
#line 311 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_DBD__SQLite__db_create_aggregate); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_create_aggregate)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items < 4 || items > 5)
       croak_xs_usage(cv,  "dbh, name, argc, aggr, flags = 0");
    {
	SV *	dbh = ST(0)
;
	char *	name = (char *)SvPV_nolen(ST(1))
;
	int	argc = (int)SvIV(ST(2))
;
	SV *	aggr = ST(3)
;
	int	flags;
	int	RETVAL;
	dXSTARG;

	if (items < 5)
	    flags = 0;
	else {
	    flags = (int)SvIV(ST(4))
;
	}
#line 104 "SQLite.xs"
    {
        RETVAL = sqlite_db_create_aggregate(aTHX_ dbh, name, argc, aggr, flags );
    }
#line 350 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__db_create_collation); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_create_collation)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 3)
       croak_xs_usage(cv,  "dbh, name, func");
    {
	SV *	dbh = ST(0)
;
	char *	name = (char *)SvPV_nolen(ST(1))
;
	SV *	func = ST(2)
;
	int	RETVAL;
	dXSTARG;
#line 118 "SQLite.xs"
    {
        RETVAL = sqlite_db_create_collation(aTHX_ dbh, name, func );
    }
#line 378 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__db_collation_needed); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_collation_needed)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 2)
       croak_xs_usage(cv,  "dbh, callback");
    {
	SV *	dbh = ST(0)
;
	SV *	callback = ST(1)
;
#line 132 "SQLite.xs"
    {
        sqlite_db_collation_needed(aTHX_ dbh, callback );
    }
#line 402 "SQLite.c"
    }
    XSRETURN_EMPTY;
}


XS_EUPXS(XS_DBD__SQLite__db_progress_handler); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_progress_handler)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 3)
       croak_xs_usage(cv,  "dbh, n_opcodes, handler");
    {
	SV *	dbh = ST(0)
;
	int	n_opcodes = (int)SvIV(ST(1))
;
	SV *	handler = ST(2)
;
	int	RETVAL;
	dXSTARG;
#line 145 "SQLite.xs"
    {
        RETVAL = sqlite_db_progress_handler(aTHX_ dbh, n_opcodes, handler );
    }
#line 428 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__db_sqlite_trace); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_sqlite_trace)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "dbh, callback");
    {
	SV *	dbh = ST(0)
;
	SV *	callback = ST(1)
;
	int	RETVAL;
	dXSTARG;
#line 156 "SQLite.xs"
    {
        RETVAL = sqlite_db_trace(aTHX_ dbh, callback );
    }
#line 453 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__db_profile); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_profile)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 2)
       croak_xs_usage(cv,  "dbh, callback");
    {
	SV *	dbh = ST(0)
;
	SV *	callback = ST(1)
;
	int	RETVAL;
	dXSTARG;
#line 169 "SQLite.xs"
    {
        RETVAL = sqlite_db_profile(aTHX_ dbh, callback );
    }
#line 479 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__db_commit_hook); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_commit_hook)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 2)
       croak_xs_usage(cv,  "dbh, hook");
    {
	SV *	dbh = ST(0)
;
	SV *	hook = ST(1)
;
	SV *	RETVAL;
#line 182 "SQLite.xs"
    {
        RETVAL = (SV*) sqlite_db_commit_hook( aTHX_ dbh, hook );
    }
#line 504 "SQLite.c"
	RETVAL = sv_2mortal(RETVAL);
	ST(0) = RETVAL;
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__db_rollback_hook); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_rollback_hook)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 2)
       croak_xs_usage(cv,  "dbh, hook");
    {
	SV *	dbh = ST(0)
;
	SV *	hook = ST(1)
;
	SV *	RETVAL;
#line 195 "SQLite.xs"
    {
        RETVAL = (SV*) sqlite_db_rollback_hook( aTHX_ dbh, hook );
    }
#line 529 "SQLite.c"
	RETVAL = sv_2mortal(RETVAL);
	ST(0) = RETVAL;
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__db_update_hook); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_update_hook)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 2)
       croak_xs_usage(cv,  "dbh, hook");
    {
	SV *	dbh = ST(0)
;
	SV *	hook = ST(1)
;
	SV *	RETVAL;
#line 208 "SQLite.xs"
    {
        RETVAL = (SV*) sqlite_db_update_hook( aTHX_ dbh, hook );
    }
#line 554 "SQLite.c"
	RETVAL = sv_2mortal(RETVAL);
	ST(0) = RETVAL;
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__db_set_authorizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_set_authorizer)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 2)
       croak_xs_usage(cv,  "dbh, authorizer");
    {
	SV *	dbh = ST(0)
;
	SV *	authorizer = ST(1)
;
	int	RETVAL;
	dXSTARG;
#line 222 "SQLite.xs"
    {
        RETVAL = sqlite_db_set_authorizer( aTHX_ dbh, authorizer );
    }
#line 580 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__db_busy_timeout); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_busy_timeout)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "dbh, timeout=NULL");
    {
	SV *	dbh = ST(0)
;
	SV *	timeout;
	int	RETVAL;
	dXSTARG;

	if (items < 2)
	    timeout = NULL;
	else {
	    timeout = ST(1)
;
	}
#line 236 "SQLite.xs"
        RETVAL = sqlite_db_busy_timeout(aTHX_ dbh, timeout );
#line 610 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__db_backup_from_file); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_backup_from_file)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 2)
       croak_xs_usage(cv,  "dbh, filename");
    {
	SV *	dbh = ST(0)
;
	char *	filename = (char *)SvPV_nolen(ST(1))
;
	int	RETVAL;
	dXSTARG;
#line 247 "SQLite.xs"
        RETVAL = sqlite_db_backup_from_file(aTHX_ dbh, filename);
#line 634 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__db_backup_to_file); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_backup_to_file)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 2)
       croak_xs_usage(cv,  "dbh, filename");
    {
	SV *	dbh = ST(0)
;
	char *	filename = (char *)SvPV_nolen(ST(1))
;
	int	RETVAL;
	dXSTARG;
#line 258 "SQLite.xs"
        RETVAL = sqlite_db_backup_to_file(aTHX_ dbh, filename);
#line 658 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__db_backup_from_dbh); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_backup_from_dbh)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 2)
       croak_xs_usage(cv,  "dbh, from");
    {
	SV *	dbh = ST(0)
;
	SV *	from = ST(1)
;
	int	RETVAL;
	dXSTARG;
#line 269 "SQLite.xs"
        RETVAL = sqlite_db_backup_from_dbh(aTHX_ dbh, from);
#line 682 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__db_backup_to_dbh); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_backup_to_dbh)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 2)
       croak_xs_usage(cv,  "dbh, to");
    {
	SV *	dbh = ST(0)
;
	SV *	to = ST(1)
;
	int	RETVAL;
	dXSTARG;
#line 280 "SQLite.xs"
        RETVAL = sqlite_db_backup_to_dbh(aTHX_ dbh, to);
#line 706 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__db_table_column_metadata); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_table_column_metadata)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 4)
       croak_xs_usage(cv,  "dbh, dbname, tablename, columnname");
    {
	SV*	dbh = ST(0)
;
	SV*	dbname = ST(1)
;
	SV*	tablename = ST(2)
;
	SV*	columnname = ST(3)
;
	HV *	RETVAL;
#line 293 "SQLite.xs"
        RETVAL = sqlite_db_table_column_metadata(aTHX_ dbh, dbname, tablename, columnname);
#line 733 "SQLite.c"
	{
	    SV * RETVALSV;
	    RETVALSV = newRV_noinc((SV*)RETVAL);
	    RETVALSV = sv_2mortal(RETVALSV);
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__db_db_filename); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_db_filename)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 1)
       croak_xs_usage(cv,  "dbh");
    {
	SV*	dbh = ST(0)
;
	SV *	RETVAL;
#line 303 "SQLite.xs"
        RETVAL = sqlite_db_filename(aTHX_ dbh);
#line 758 "SQLite.c"
	RETVAL = sv_2mortal(RETVAL);
	ST(0) = RETVAL;
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__db_register_fts3_perl_tokenizer); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_register_fts3_perl_tokenizer)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 1)
       croak_xs_usage(cv,  "dbh");
    {
	SV *	dbh = ST(0)
;
	int	RETVAL;
	dXSTARG;
#line 313 "SQLite.xs"
        RETVAL = sqlite_db_register_fts3_perl_tokenizer(aTHX_ dbh);
#line 780 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__db_db_status); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_db_status)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "dbh, reset = 0");
    {
	SV*	dbh = ST(0)
;
	int	reset;
	HV *	RETVAL;

	if (items < 2)
	    reset = 0;
	else {
	    reset = (int)SvIV(ST(1))
;
	}
#line 324 "SQLite.xs"
        RETVAL = (HV*)_sqlite_db_status(aTHX_ dbh, reset);
#line 809 "SQLite.c"
	{
	    SV * RETVALSV;
	    RETVALSV = newRV_noinc((SV*)RETVAL);
	    RETVALSV = sv_2mortal(RETVALSV);
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__db_create_module); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_create_module)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 3)
       croak_xs_usage(cv,  "dbh, name, perl_class");
    {
	SV *	dbh = ST(0)
;
	char *	name = (char *)SvPV_nolen(ST(1))
;
	char *	perl_class = (char *)SvPV_nolen(ST(2))
;
	int	RETVAL;
	dXSTARG;
#line 337 "SQLite.xs"
    {
        RETVAL = sqlite_db_create_module(aTHX_ dbh, name, perl_class);
    }
#line 841 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__db_limit); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_limit)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "dbh, id, new_value = -1");
    {
	SV *	dbh = ST(0)
;
	int	id = (int)SvIV(ST(1))
;
	int	new_value;
	int	RETVAL;
	dXSTARG;

	if (items < 3)
	    new_value = -1;
	else {
	    new_value = (int)SvIV(ST(2))
;
	}
#line 351 "SQLite.xs"
    {
        RETVAL = sqlite_db_limit(aTHX_ dbh, id, new_value);
    }
#line 875 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__db_db_config); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_db_config)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "dbh, id, new_value = -1");
    {
	SV *	dbh = ST(0)
;
	int	id = (int)SvIV(ST(1))
;
	int	new_value;
	int	RETVAL;
	dXSTARG;

	if (items < 3)
	    new_value = -1;
	else {
	    new_value = (int)SvIV(ST(2))
;
	}
#line 365 "SQLite.xs"
    {
        RETVAL = sqlite_db_config(aTHX_ dbh, id, new_value);
    }
#line 909 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__db_get_autocommit); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_get_autocommit)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 1)
       croak_xs_usage(cv,  "dbh");
    {
	SV *	dbh = ST(0)
;
	int	RETVAL;
	dXSTARG;
#line 377 "SQLite.xs"
    {
        RETVAL = sqlite_db_get_autocommit(aTHX_ dbh);
    }
#line 933 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__db_txn_state); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_txn_state)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "dbh, schema= &PL_sv_undef");
    {
	int	RETVAL;
	dXSTARG;
	SV*	dbh = ST(0)
;
	SV *	schema;

	if (items < 2)
	    schema = &PL_sv_undef;
	else {
	    schema = ST(1)
;
	}
#line 388 "SQLite.xs"
    {
        RETVAL = sqlite_db_txn_state(aTHX_ dbh, schema);
    }
#line 965 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__db_error_offset); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_error_offset)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 1)
       croak_xs_usage(cv,  "dbh");
    {
	SV *	dbh = ST(0)
;
	int	RETVAL;
	dXSTARG;
#line 400 "SQLite.xs"
    {
#if SQLITE_VERSION_NUMBER >= 3038000
        D_imp_dbh(dbh);
        RETVAL = sqlite3_error_offset(imp_dbh->db);
#else
        RETVAL = -1;
#endif
    }
#line 994 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__st_st_status); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__st_st_status)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "sth, reset = 0");
    {
	SV*	sth = ST(0)
;
	int	reset;
	HV *	RETVAL;

	if (items < 2)
	    reset = 0;
	else {
	    reset = (int)SvIV(ST(1))
;
	}
#line 423 "SQLite.xs"
        RETVAL = (HV*)_sqlite_st_status(aTHX_ sth, reset);
#line 1023 "SQLite.c"
	{
	    SV * RETVALSV;
	    RETVALSV = newRV_noinc((SV*)RETVAL);
	    RETVALSV = sv_2mortal(RETVALSV);
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite_compile_options); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite_compile_options)
{
    dVAR; dXSARGS;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	int	RETVAL;
	dXSTARG;
#line 436 "SQLite.xs"
        int n = 0;
        AV* av = (AV*)sqlite_compile_options();
        if (av) {
            int i;
            n = av_len(av) + 1;
            EXTEND(sp, n);
            for (i = 0; i < n; i++) {
                PUSHs(AvARRAY(av)[i]);
            }
        }
        XSRETURN(n);
#line 1056 "SQLite.c"
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite_sqlite_status); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite_sqlite_status)
{
    dVAR; dXSARGS;
    if (items < 0 || items > 1)
       croak_xs_usage(cv,  "reset = 0");
    {
	int	reset;
	HV *	RETVAL;

	if (items < 1)
	    reset = 0;
	else {
	    reset = (int)SvIV(ST(0))
;
	}
#line 452 "SQLite.xs"
        RETVAL = (HV*)_sqlite_status(reset);
#line 1080 "SQLite.c"
	{
	    SV * RETVALSV;
	    RETVALSV = newRV_noinc((SV*)RETVAL);
	    RETVALSV = sv_2mortal(RETVALSV);
	    ST(0) = RETVALSV;
	}
    }
    XSRETURN(1);
}

#if SQLITE_VERSION_NUMBER >= 3010000
#define XSubPPtmpAAAB 1


XS_EUPXS(XS_DBD__SQLite_strglob); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite_strglob)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "zglob, zstr");
    {
	int	RETVAL;
	dXSTARG;
	const char *	zglob = (const char *)SvPV_nolen(ST(0))
;
	const char *	zstr = (const char *)SvPV_nolen(ST(1))
;
#line 461 "SQLite.xs"
        RETVAL = sqlite3_strglob(zglob, zstr);
#line 1110 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite_strlike); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite_strlike)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "zglob, zstr, esc= NULL");
    {
	int	RETVAL;
	dXSTARG;
	const char *	zglob = (const char *)SvPV_nolen(ST(0))
;
	const char *	zstr = (const char *)SvPV_nolen(ST(1))
;
	const char *	esc;

	if (items < 3)
	    esc = NULL;
	else {
	    esc = (const char *)SvPV_nolen(ST(2))
;
	}
#line 468 "SQLite.xs"
        if (esc) {
            RETVAL = sqlite3_strlike(zglob, zstr, (unsigned int)(*esc));
        } else {
            RETVAL = sqlite3_strlike(zglob, zstr, 0);
        }
#line 1145 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

/* INCLUDE:  Including 'constants.inc' from 'SQLite.xs' */


/* INCLUDE:  Including 'SQLite.xsi' from 'constants.inc' */

#include "Driver_xst.h"
#if defined(dbd_st_execute_iv)
#undef dbd_st_execute
#define dbd_st_execute dbd_st_execute_iv
#endif
#if defined(dbd_st_rows_iv)
#undef dbd_st_rows
#define dbd_st_rows dbd_st_rows_iv
#endif
#if defined(dbd_db_do4_iv)
#undef dbd_db_do4
#define dbd_db_do4 dbd_db_do4_iv
#endif

XS_EUPXS(XS_DBD__SQLite__dr_dbixs_revision); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__dr_dbixs_revision)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
#line 58 "./SQLite.xsi"
    ST(0) = sv_2mortal(newSViv(DBIXS_REVISION));
#line 1184 "SQLite.c"
	PUTBACK;
	return;
    }
}

#ifdef dbd_discon_all
#define XSubPPtmpAAAC 1


XS_EUPXS(XS_DBD__SQLite__dr_discon_all_); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__dr_discon_all_)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 1)
       croak_xs_usage(cv,  "drh");
    {
	SV *	drh = ST(0)
;
	bool	RETVAL;
#line 70 "./SQLite.xsi"
    D_imp_drh(drh);
    PERL_UNUSED_VAR(ix);
    RETVAL = dbd_discon_all(drh, imp_drh);
#line 1209 "SQLite.c"
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif /* dbd_discon_all */
#ifdef dbd_dr_data_sources
#define XSubPPtmpAAAD 1


XS_EUPXS(XS_DBD__SQLite__dr_data_sources); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__dr_data_sources)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "drh, attr = Nullsv");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	SV *	drh = ST(0)
;
	SV *	attr;

	if (items < 2)
	    attr = Nullsv;
	else {
	    attr = ST(1)
;
	}
#line 86 "./SQLite.xsi"
    {
        D_imp_drh(drh);
        AV *av = dbd_dr_data_sources(drh, imp_drh, attr);
        if (av) {
            int i;
            int n = AvFILL(av)+1;
            EXTEND(sp, n);
            for (i = 0; i < n; ++i) {
                PUSHs(AvARRAY(av)[i]);
            }
        }
    }
#line 1252 "SQLite.c"
	PUTBACK;
	return;
    }
}

#endif

XS_EUPXS(XS_DBD__SQLite__db__login); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db__login)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 5)
       croak_xs_usage(cv,  "dbh, dbname, username, password, attribs=Nullsv");
    {
	SV *	dbh = ST(0)
;
	SV *	dbname = ST(1)
;
	SV *	username = ST(2)
;
	SV *	password = ST(3)
;
	SV *	attribs;
	bool	RETVAL;

	if (items < 5)
	    attribs = Nullsv;
	else {
	    attribs = ST(4)
;
	}
#line 116 "./SQLite.xsi"
    {
    D_imp_dbh(dbh);
#if !defined(dbd_db_login6_sv)
    STRLEN lna;
    char *u = (SvOK(username)) ? SvPV(username,lna) : (char*)"";
    char *p = (SvOK(password)) ? SvPV(password,lna) : (char*)"";
#endif
#ifdef dbd_db_login6_sv
    RETVAL = dbd_db_login6_sv(dbh, imp_dbh, dbname, username, password, attribs);
#elif defined(dbd_db_login6)
    RETVAL = dbd_db_login6(dbh, imp_dbh, SvPV_nolen(dbname), u, p, attribs);
#else
    PERL_UNUSED_ARG(attribs);
    RETVAL = dbd_db_login( dbh, imp_dbh, SvPV_nolen(dbname), u, p);
#endif
    }
#line 1301 "SQLite.c"
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__db_selectall_arrayref); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_selectall_arrayref)
{
    dVAR; dXSARGS;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    {
#line 139 "./SQLite.xsi"
    SV *sth;
    SV **maxrows_svp;
    SV **tmp_svp;
    SV *tmp_sv;
    SV *attr = &PL_sv_undef;
    imp_sth_t *imp_sth;
#line 1322 "SQLite.c"
#line 146 "./SQLite.xsi"
    if (items > 2) {
        attr = ST(2);
        if (SvROK(attr) &&
                (DBD_ATTRIB_TRUE(attr,"Slice",5,tmp_svp) || DBD_ATTRIB_TRUE(attr,"Columns",7,tmp_svp))
        ) {
            /* fallback to perl implementation */
            SV *tmp =dbixst_bounce_method("DBD::SQLite::db::SUPER::selectall_arrayref", items);
            SPAGAIN;
            ST(0) = tmp;
            XSRETURN(1);
        }
    }
    /* --- prepare --- */
    if (SvROK(ST(1))) {
        MAGIC *mg;
        sth = ST(1);
        /* switch to inner handle if not already */
        if ( (mg = mg_find(SvRV(sth),'P')) )
            sth = mg->mg_obj;
    }
    else {
        sth = dbixst_bounce_method("prepare", 3);
        SPAGAIN; SP -= items; /* because stack might have been realloc'd */
        if (!SvROK(sth))
            XSRETURN_UNDEF;
        /* switch to inner handle */
        sth = mg_find(SvRV(sth),'P')->mg_obj;
    }
    imp_sth = (imp_sth_t*)(DBIh_COM(sth));
    /* --- bind_param --- */
    if (items > 3) {    /* need to bind params before execute */
        if (!dbdxst_bind_params(sth, imp_sth, items-2, ax+2) ) {
            XSRETURN_UNDEF;
        }
    }
    /* --- execute --- */
    DBIc_ROW_COUNT(imp_sth) = 0;
    if ( dbd_st_execute(sth, imp_sth) <= -2 ) { /* -2 == error */
        XSRETURN_UNDEF;
    }
    /* --- fetchall --- */
    maxrows_svp = DBD_ATTRIB_GET_SVP(attr, "MaxRows", 7);
    tmp_sv = dbdxst_fetchall_arrayref(sth, &PL_sv_undef, (maxrows_svp) ? *maxrows_svp : &PL_sv_undef);
    SPAGAIN;
    ST(0) = tmp_sv;
#line 1369 "SQLite.c"
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__db_selectrow_arrayref); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_selectrow_arrayref)
{
    dVAR; dXSARGS;
    dXSI32;
    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
#line 198 "./SQLite.xsi"
    int is_selectrow_array = (ix == 1);
    imp_sth_t *imp_sth;
    SV *sth;
    AV *row_av;
#line 1390 "SQLite.c"
#line 203 "./SQLite.xsi"
    if (SvROK(ST(1))) {
        MAGIC *mg;
        sth = ST(1);
        /* switch to inner handle if not already */
        if ( (mg = mg_find(SvRV(sth),'P')) )
            sth = mg->mg_obj;
    }
    else {
        /* --- prepare --- */
        sth = dbixst_bounce_method("prepare", 3);
        SPAGAIN; SP -= items; /* because stack might have been realloc'd */
        if (!SvROK(sth)) {
            if (is_selectrow_array) { XSRETURN_EMPTY; } else { XSRETURN_UNDEF; }
        }
        /* switch to inner handle */
        sth = mg_find(SvRV(sth),'P')->mg_obj;
    }
    imp_sth = (imp_sth_t*)(DBIh_COM(sth));
    /* --- bind_param --- */
    if (items > 3) {    /* need to bind params before execute */
        if (!dbdxst_bind_params(sth, imp_sth, items-2, ax+2) ) {
            if (is_selectrow_array) { XSRETURN_EMPTY; } else { XSRETURN_UNDEF; }
        }
    }
    /* --- execute --- */
    DBIc_ROW_COUNT(imp_sth) = 0;
    if ( dbd_st_execute(sth, imp_sth) <= -2 ) { /* -2 == error */
        if (is_selectrow_array) { XSRETURN_EMPTY; } else { XSRETURN_UNDEF; }
    }
    /* --- fetchrow_arrayref --- */
    row_av = dbd_st_fetch(sth, imp_sth);
    if (!row_av) {
        if (GIMME_V == G_SCALAR)
            PUSHs(&PL_sv_undef);
    }
    else if (is_selectrow_array) {
        int i;
        int num_fields = AvFILL(row_av)+1;
        if (GIMME_V == G_SCALAR)
            num_fields = 1; /* return just first field */
        EXTEND(sp, num_fields);
        for(i=0; i < num_fields; ++i) {
            PUSHs(AvARRAY(row_av)[i]);
        }
    }
    else {
        PUSHs( sv_2mortal(newRV((SV *)row_av)) );
    }
    /* --- finish --- */
#ifdef dbd_st_finish3
    dbd_st_finish3(sth, imp_sth, 0);
#else
    dbd_st_finish(sth, imp_sth);
#endif
#line 1446 "SQLite.c"
	PUTBACK;
	return;
    }
}

#if defined(dbd_db_do6) || defined(dbd_db_do4)
#define XSubPPtmpAAAE 1


XS_EUPXS(XS_DBD__SQLite__db_do); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_do)
{
    dVAR; dXSARGS;
    if (items < 2)
       croak_xs_usage(cv,  "dbh, statement, params = Nullsv, ...");
    {
	SV *	dbh = ST(0)
;
	SV *	statement = ST(1)
;
	SV *	params;

	if (items < 3)
	    params = Nullsv;
	else {
	    params = ST(2)
;
	}
#line 267 "./SQLite.xsi"
    {
    D_imp_dbh(dbh);
    IV retval;
#ifdef dbd_db_do6
    /* items is a number of arguments passed to XSUB, supplied by xsubpp compiler */
    /* ax contains stack base offset used by ST() macro, supplied by xsubpp compiler */
    I32 offset = (items >= 3) ? 3 : items;
    retval = dbd_db_do6(dbh, imp_dbh, statement, params, items-offset, ax+offset);
#else
    if (items > 3)
        croak_xs_usage(cv,  "dbh, statement, params = Nullsv");
    retval = dbd_db_do4(dbh, imp_dbh, SvPV_nolen(statement), params); /* might be dbd_db_do4_iv via macro */
#endif
    /* remember that dbd_db_do* must return <= -2 for error     */
    if (retval == 0)            /* ok with no rows affected     */
        XST_mPV(0, "0E0");      /* (true but zero)              */
    else if (retval < -1)       /* -1 == unknown number of rows */
        XST_mUNDEF(0);          /* <= -2 means error            */
    else
        XST_mIV(0, retval);     /* typically 1, rowcount or -1  */
    }
#line 1497 "SQLite.c"
    }
    XSRETURN(1);
}

#endif
#ifdef dbd_db_last_insert_id
#define XSubPPtmpAAAF 1


XS_EUPXS(XS_DBD__SQLite__db_last_insert_id); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_last_insert_id)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 6)
       croak_xs_usage(cv,  "dbh, catalog=&PL_sv_undef, schema=&PL_sv_undef, table=&PL_sv_undef, field=&PL_sv_undef, attr=Nullsv");
    {
	SV *	dbh = ST(0)
;
	SV *	catalog;
	SV *	schema;
	SV *	table;
	SV *	field;
	SV *	attr;

	if (items < 2)
	    catalog = &PL_sv_undef;
	else {
	    catalog = ST(1)
;
	}

	if (items < 3)
	    schema = &PL_sv_undef;
	else {
	    schema = ST(2)
;
	}

	if (items < 4)
	    table = &PL_sv_undef;
	else {
	    table = ST(3)
;
	}

	if (items < 5)
	    field = &PL_sv_undef;
	else {
	    field = ST(4)
;
	}

	if (items < 6)
	    attr = Nullsv;
	else {
	    attr = ST(5)
;
	}
#line 303 "./SQLite.xsi"
    {
    D_imp_dbh(dbh);
    SV *ret = dbd_db_last_insert_id(dbh, imp_dbh, catalog, schema, table, field, attr);
    ST(0) = ret;
    }
#line 1562 "SQLite.c"
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_DBD__SQLite__db_commit); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_commit)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "dbh");
    {
	SV *	dbh = ST(0)
;
	bool	RETVAL;
#line 316 "./SQLite.xsi"
    D_imp_dbh(dbh);
    if (DBIc_has(imp_dbh,DBIcf_AutoCommit) && DBIc_WARN(imp_dbh))
        warn("commit ineffective with AutoCommit enabled");
    RETVAL = dbd_db_commit(dbh, imp_dbh);
#line 1584 "SQLite.c"
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__db_rollback); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_rollback)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "dbh");
    {
	SV *	dbh = ST(0)
;
	bool	RETVAL;
#line 328 "./SQLite.xsi"
    D_imp_dbh(dbh);
    if (DBIc_has(imp_dbh,DBIcf_AutoCommit) && DBIc_WARN(imp_dbh))
        warn("rollback ineffective with AutoCommit enabled");
    RETVAL = dbd_db_rollback(dbh, imp_dbh);
#line 1606 "SQLite.c"
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__db_disconnect); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_disconnect)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "dbh");
    {
	SV *	dbh = ST(0)
;
	bool	RETVAL;
#line 340 "./SQLite.xsi"
    D_imp_dbh(dbh);
    if ( !DBIc_ACTIVE(imp_dbh) ) {
        XSRETURN_YES;
    }
    /* Check for disconnect() being called whilst refs to cursors       */
    /* still exists. This possibly needs some more thought.             */
    if (DBIc_ACTIVE_KIDS(imp_dbh) && DBIc_WARN(imp_dbh) && !PL_dirty) {
        STRLEN lna;
        char *plural = (DBIc_ACTIVE_KIDS(imp_dbh)==1) ? (char*)"" : (char*)"s";
        warn("%s->disconnect invalidates %d active statement handle%s %s",
            SvPV(dbh,lna), (int)DBIc_ACTIVE_KIDS(imp_dbh), plural,
            "(either destroy statement handles or call finish on them before disconnecting)");
    }
    RETVAL = dbd_db_disconnect(dbh, imp_dbh);
    DBIc_ACTIVE_off(imp_dbh);   /* ensure it's off, regardless */
#line 1639 "SQLite.c"
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__db_STORE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_STORE)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "dbh, keysv, valuesv");
    {
	SV *	dbh = ST(0)
;
	SV *	keysv = ST(1)
;
	SV *	valuesv = ST(2)
;
#line 365 "./SQLite.xsi"
    D_imp_dbh(dbh);
    if (SvGMAGICAL(valuesv))
        mg_get(valuesv);
    ST(0) = &PL_sv_yes;
    if (!dbd_db_STORE_attrib(dbh, imp_dbh, keysv, valuesv))
        if (!DBIc_DBISTATE(imp_dbh)->set_attr(dbh, keysv, valuesv))
            ST(0) = &PL_sv_no;
#line 1667 "SQLite.c"
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__db_FETCH); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_FETCH)
{
    dVAR; dXSARGS;
    if (items != 2)
       croak_xs_usage(cv,  "dbh, keysv");
    {
	SV *	dbh = ST(0)
;
	SV *	keysv = ST(1)
;
#line 379 "./SQLite.xsi"
    D_imp_dbh(dbh);
    SV *valuesv = dbd_db_FETCH_attrib(dbh, imp_dbh, keysv);
    if (!valuesv)
        valuesv = DBIc_DBISTATE(imp_dbh)->get_attr(dbh, keysv);
    ST(0) = valuesv;    /* dbd_db_FETCH_attrib did sv_2mortal   */
#line 1690 "SQLite.c"
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__db_DESTROY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_DESTROY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "dbh");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	SV *	dbh = ST(0)
;
#line 390 "./SQLite.xsi"
    /* keep in sync with default DESTROY in DBI.xs */
    D_imp_dbh(dbh);
    ST(0) = &PL_sv_yes;
    if (!DBIc_IMPSET(imp_dbh)) {        /* was never fully set up       */
        STRLEN lna;
        if (DBIc_WARN(imp_dbh) && !PL_dirty && DBIc_DBISTATE(imp_dbh)->debug >= 2)
             PerlIO_printf(DBIc_LOGPIO(imp_dbh),
                "         DESTROY for %s ignored - handle not initialised\n",
                    SvPV(dbh,lna));
    }
    else {
        if (DBIc_IADESTROY(imp_dbh)) {            /* wants ineffective destroy */
            DBIc_ACTIVE_off(imp_dbh);
            if (DBIc_DBISTATE(imp_dbh)->debug)
                 PerlIO_printf(DBIc_LOGPIO(imp_dbh), "         DESTROY %s skipped due to InactiveDestroy\n", SvPV_nolen(dbh));
        }
        if (DBIc_ACTIVE(imp_dbh)) {
            if (!DBIc_has(imp_dbh,DBIcf_AutoCommit)) {
                /* Application is using transactions and hasn't explicitly disconnected.
                    Some databases will automatically commit on graceful disconnect.
                    Since we're about to gracefully disconnect as part of the DESTROY
                    we want to be sure we're not about to implicitly commit changes
                    that are incomplete and should be rolled back. (The DESTROY may
                    be due to a RaiseError, for example.) So we rollback here.
                    This will be harmless if the application has issued a commit,
                    XXX Could add an attribute flag to indicate that the driver
                    doesn't have this problem. Patches welcome.
                */
                if (DBIc_WARN(imp_dbh) /* only warn if likely to be useful... */
                &&  DBIc_is(imp_dbh, DBIcf_Executed) /* has not just called commit/rollback */
            /*  && !DBIc_is(imp_dbh, DBIcf_ReadOnly) -- is not read only */
                && (!PL_dirty || DBIc_DBISTATE(imp_dbh)->debug >= 3)
                ) {
                    warn("Issuing rollback() due to DESTROY without explicit disconnect() of %s handle %s",
                        SvPV_nolen(*hv_fetch((HV*)SvRV(dbh), "ImplementorClass", 16, 1)),
                        SvPV_nolen(*hv_fetch((HV*)SvRV(dbh), "Name", 4, 1))
                    );
                }
                dbd_db_rollback(dbh, imp_dbh);                  /* ROLLBACK! */
            }
            dbd_db_disconnect(dbh, imp_dbh);
            DBIc_ACTIVE_off(imp_dbh);   /* ensure it's off, regardless */
        }
        dbd_db_destroy(dbh, imp_dbh);
    }
#line 1753 "SQLite.c"
	PUTBACK;
	return;
    }
}

#ifdef dbd_take_imp_data
#define XSubPPtmpAAAG 1


XS_EUPXS(XS_DBD__SQLite__db_take_imp_data); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_take_imp_data)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "h");
    {
	SV *	h = ST(0)
;
#line 443 "./SQLite.xsi"
    D_imp_xxh(h);
    /* dbd_take_imp_data() returns &sv_no (or other defined but false value)
     * to indicate "preparations complete, now call SUPER::take_imp_data" for me.
     * Anything else is returned to the caller via sv_2mortal(sv), typically that
     * would be &sv_undef for error or an SV holding the imp_data.
     */
    SV *sv = dbd_take_imp_data(h, imp_xxh, NULL);
    if (SvOK(sv) && !SvTRUE(sv)) {
        SV *tmp = dbixst_bounce_method("DBD::SQLite::db::SUPER::take_imp_data", items);
        SPAGAIN;
        ST(0) = tmp;
    } else {
        ST(0) = sv_2mortal(sv);
    }
#line 1787 "SQLite.c"
    }
    XSRETURN(1);
}

#endif
#ifdef dbd_db_data_sources
#define XSubPPtmpAAAH 1


XS_EUPXS(XS_DBD__SQLite__db_data_sources); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__db_data_sources)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 2)
       croak_xs_usage(cv,  "dbh, attr = Nullsv");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	SV *	dbh = ST(0)
;
	SV *	attr;

	if (items < 2)
	    attr = Nullsv;
	else {
	    attr = ST(1)
;
	}
#line 467 "./SQLite.xsi"
    {
        D_imp_dbh(dbh);
        AV *av = dbd_db_data_sources(dbh, imp_dbh, attr);
        if (av) {
            int i;
            int n = AvFILL(av)+1;
            EXTEND(sp, n);
            for (i = 0; i < n; ++i) {
                PUSHs(AvARRAY(av)[i]);
            }
        }
    }
#line 1829 "SQLite.c"
	PUTBACK;
	return;
    }
}

#endif

XS_EUPXS(XS_DBD__SQLite__st__prepare); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__st__prepare)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "sth, statement, attribs=Nullsv");
    {
	SV *	sth = ST(0)
;
	SV *	statement = ST(1)
;
	SV *	attribs;
	bool	RETVAL;

	if (items < 3)
	    attribs = Nullsv;
	else {
	    attribs = ST(2)
;
	}
#line 496 "./SQLite.xsi"
    {
    D_imp_sth(sth);
    DBD_ATTRIBS_CHECK("_prepare", sth, attribs);
#ifdef dbd_st_prepare_sv
    RETVAL = dbd_st_prepare_sv(sth, imp_sth, statement, attribs);
#else
    RETVAL = dbd_st_prepare(sth, imp_sth, SvPV_nolen(statement), attribs);
#endif
    }
#line 1867 "SQLite.c"
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#ifdef dbd_st_rows
#define XSubPPtmpAAAI 1


XS_EUPXS(XS_DBD__SQLite__st_rows); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__st_rows)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "sth");
    {
	SV *	sth = ST(0)
;
#line 515 "./SQLite.xsi"
    D_imp_sth(sth);
    XST_mIV(0, dbd_st_rows(sth, imp_sth));
#line 1889 "SQLite.c"
    }
    XSRETURN(1);
}

#endif /* dbd_st_rows */
#ifdef dbd_st_bind_col
#define XSubPPtmpAAAJ 1


XS_EUPXS(XS_DBD__SQLite__st_bind_col); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__st_bind_col)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 4)
       croak_xs_usage(cv,  "sth, col, ref, attribs=Nullsv");
    {
	SV *	sth = ST(0)
;
	SV *	col = ST(1)
;
	SV *	ref = ST(2)
;
	SV *	attribs;
	bool	RETVAL;

	if (items < 4)
	    attribs = Nullsv;
	else {
	    attribs = ST(3)
;
	}
#line 530 "./SQLite.xsi"
    {
    IV sql_type = 0;
    D_imp_sth(sth);
    if (SvGMAGICAL(ref))
        mg_get(ref);
    if (attribs) {
        if (SvNIOK(attribs)) {
            sql_type = SvIV(attribs);
            attribs = Nullsv;
        }
        else {
            SV **svp;
            DBD_ATTRIBS_CHECK("bind_col", sth, attribs);
            /* XXX we should perhaps complain if TYPE is not SvNIOK */
            DBD_ATTRIB_GET_IV(attribs, "TYPE",4, svp, sql_type);
        }
    }
    switch(dbd_st_bind_col(sth, imp_sth, col, ref, sql_type, attribs)) {
    case 2:     RETVAL = TRUE;              /* job done completely */
                break;
    case 1:     /* fallback to DBI default */
                RETVAL = DBIc_DBISTATE(imp_sth)->bind_col(sth, col, ref, attribs);
                break;
    default:    RETVAL = FALSE;             /* dbd_st_bind_col has called set_err */
                break;
    }
    }
#line 1949 "SQLite.c"
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}

#endif /* dbd_st_bind_col */

XS_EUPXS(XS_DBD__SQLite__st_bind_param); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__st_bind_param)
{
    dVAR; dXSARGS;
    if (items < 3 || items > 4)
       croak_xs_usage(cv,  "sth, param, value, attribs=Nullsv");
    {
	SV *	sth = ST(0)
;
	SV *	param = ST(1)
;
	SV *	value = ST(2)
;
	SV *	attribs;
	bool	RETVAL;

	if (items < 4)
	    attribs = Nullsv;
	else {
	    attribs = ST(3)
;
	}
#line 569 "./SQLite.xsi"
    {
    IV sql_type = 0;
    D_imp_sth(sth);
    if (SvGMAGICAL(value))
        mg_get(value);
    if (attribs) {
        if (SvNIOK(attribs)) {
            sql_type = SvIV(attribs);
            attribs = Nullsv;
        }
        else {
            SV **svp;
            DBD_ATTRIBS_CHECK("bind_param", sth, attribs);
            /* XXX we should perhaps complain if TYPE is not SvNIOK */
            DBD_ATTRIB_GET_IV(attribs, "TYPE",4, svp, sql_type);
        }
    }
    RETVAL = dbd_bind_ph(sth, imp_sth, param, value, sql_type, attribs, FALSE, 0);
    }
#line 1999 "SQLite.c"
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__st_bind_param_inout); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__st_bind_param_inout)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 5)
       croak_xs_usage(cv,  "sth, param, value_ref, maxlen, attribs=Nullsv");
    {
	SV *	sth = ST(0)
;
	SV *	param = ST(1)
;
	SV *	value_ref = ST(2)
;
	IV	maxlen = (IV)SvIV(ST(3))
;
	SV *	attribs;
	bool	RETVAL;

	if (items < 5)
	    attribs = Nullsv;
	else {
	    attribs = ST(4)
;
	}
#line 600 "./SQLite.xsi"
    {
    IV sql_type = 0;
    D_imp_sth(sth);
    SV *value;
    if (!SvROK(value_ref) || SvTYPE(SvRV(value_ref)) > SVt_PVMG)
        croak("bind_param_inout needs a reference to a scalar value");
    value = SvRV(value_ref);
    if (SvREADONLY(value))
        croak("Modification of a read-only value attempted");
    if (SvGMAGICAL(value))
        mg_get(value);
    if (attribs) {
        if (SvNIOK(attribs)) {
            sql_type = SvIV(attribs);
            attribs = Nullsv;
        }
        else {
            SV **svp;
            DBD_ATTRIBS_CHECK("bind_param", sth, attribs);
            DBD_ATTRIB_GET_IV(attribs, "TYPE",4, svp, sql_type);
        }
    }
    RETVAL = dbd_bind_ph(sth, imp_sth, param, value, sql_type, attribs, TRUE, maxlen);
    }
#line 2055 "SQLite.c"
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__st_execute); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__st_execute)
{
    dVAR; dXSARGS;
    if (items < 1)
       croak_xs_usage(cv,  "sth, ...");
    {
	SV *	sth = ST(0)
;
#line 632 "./SQLite.xsi"
    D_imp_sth(sth);
    IV retval;
    if (items > 1) {    /* need to bind params */
        if (!dbdxst_bind_params(sth, imp_sth, items, ax) ) {
            XSRETURN_UNDEF;
        }
    }
    /* XXX this code is duplicated in selectrow_arrayref above  */
    DBIc_ROW_COUNT(imp_sth) = 0;
    retval = dbd_st_execute(sth, imp_sth); /* might be dbd_st_execute_iv via macro */
    /* remember that dbd_st_execute must return <= -2 for error */
    if (retval == 0)            /* ok with no rows affected     */
        XST_mPV(0, "0E0");      /* (true but zero)              */
    else if (retval < -1)       /* -1 == unknown number of rows */
        XST_mUNDEF(0);          /* <= -2 means error            */
    else
        XST_mIV(0, retval);     /* typically 1, rowcount or -1  */
#line 2089 "SQLite.c"
    }
    XSRETURN(1);
}

#ifdef dbd_st_execute_for_fetch
#define XSubPPtmpAAAK 1


XS_EUPXS(XS_DBD__SQLite__st_execute_for_fetch); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__st_execute_for_fetch)
{
    dVAR; dXSARGS;
    if (items < 2 || items > 3)
       croak_xs_usage(cv,  "sth, fetch_tuple_sub, tuple_status = Nullsv");
    {
	SV *	sth = ST(0)
;
	SV *	fetch_tuple_sub = ST(1)
;
	SV *	tuple_status;

	if (items < 3)
	    tuple_status = Nullsv;
	else {
	    tuple_status = ST(2)
;
	}
#line 659 "./SQLite.xsi"
    {
    D_imp_sth(sth);
    SV *ret = dbd_st_execute_for_fetch(sth, imp_sth, fetch_tuple_sub, tuple_status);
    ST(0) = ret;
    }
#line 2123 "SQLite.c"
    }
    XSRETURN(1);
}

#endif
#ifdef dbd_st_last_insert_id
#define XSubPPtmpAAAL 1


XS_EUPXS(XS_DBD__SQLite__st_last_insert_id); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__st_last_insert_id)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 6)
       croak_xs_usage(cv,  "sth, catalog=&PL_sv_undef, schema=&PL_sv_undef, table=&PL_sv_undef, field=&PL_sv_undef, attr=Nullsv");
    {
	SV *	sth = ST(0)
;
	SV *	catalog;
	SV *	schema;
	SV *	table;
	SV *	field;
	SV *	attr;

	if (items < 2)
	    catalog = &PL_sv_undef;
	else {
	    catalog = ST(1)
;
	}

	if (items < 3)
	    schema = &PL_sv_undef;
	else {
	    schema = ST(2)
;
	}

	if (items < 4)
	    table = &PL_sv_undef;
	else {
	    table = ST(3)
;
	}

	if (items < 5)
	    field = &PL_sv_undef;
	else {
	    field = ST(4)
;
	}

	if (items < 6)
	    attr = Nullsv;
	else {
	    attr = ST(5)
;
	}
#line 679 "./SQLite.xsi"
    {
    D_imp_sth(sth);
    SV *ret = dbd_st_last_insert_id(sth, imp_sth, catalog, schema, table, field, attr);
    ST(0) = ret;
    }
#line 2188 "SQLite.c"
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_DBD__SQLite__st_fetchrow_arrayref); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__st_fetchrow_arrayref)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 1)
       croak_xs_usage(cv,  "sth");
    {
	SV *	sth = ST(0)
;
#line 694 "./SQLite.xsi"
    D_imp_sth(sth);
    AV *av;
    PERL_UNUSED_VAR(ix);
    av = dbd_st_fetch(sth, imp_sth);
    ST(0) = (av) ? sv_2mortal(newRV((SV *)av)) : &PL_sv_undef;
#line 2211 "SQLite.c"
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__st_fetchrow_array); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__st_fetchrow_array)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 1)
       croak_xs_usage(cv,  "sth");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	SV *	sth = ST(0)
;
#line 707 "./SQLite.xsi"
    D_imp_sth(sth);
    AV *av;
    av = dbd_st_fetch(sth, imp_sth);
    if (av) {
        int i;
        int num_fields = AvFILL(av)+1;
        EXTEND(sp, num_fields);
        for(i=0; i < num_fields; ++i) {
            PUSHs(AvARRAY(av)[i]);
        }
        PERL_UNUSED_VAR(ix);
    }
#line 2242 "SQLite.c"
	PUTBACK;
	return;
    }
}


XS_EUPXS(XS_DBD__SQLite__st_fetchall_arrayref); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__st_fetchall_arrayref)
{
    dVAR; dXSARGS;
    if (items < 1 || items > 3)
       croak_xs_usage(cv,  "sth, slice=&PL_sv_undef, batch_row_count=&PL_sv_undef");
    {
	SV *	sth = ST(0)
;
	SV *	slice;
	SV *	batch_row_count;

	if (items < 2)
	    slice = &PL_sv_undef;
	else {
	    slice = ST(1)
;
	}

	if (items < 3)
	    batch_row_count = &PL_sv_undef;
	else {
	    batch_row_count = ST(2)
;
	}
#line 727 "./SQLite.xsi"
    if (SvOK(slice)) {  /* fallback to perl implementation */
        SV *tmp = dbixst_bounce_method("DBD::SQLite::st::SUPER::fetchall_arrayref", 3);
        SPAGAIN;
        ST(0) = tmp;
    }
    else {
        SV *tmp = dbdxst_fetchall_arrayref(sth, slice, batch_row_count);
        SPAGAIN;
        ST(0) = tmp;
    }
#line 2285 "SQLite.c"
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__st_finish); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__st_finish)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "sth");
    {
	SV *	sth = ST(0)
;
	bool	RETVAL;
#line 743 "./SQLite.xsi"
    D_imp_sth(sth);
    D_imp_dbh_from_sth;
    if (!DBIc_ACTIVE(imp_sth)) {
        /* No active statement to finish        */
        XSRETURN_YES;
    }
    if (!DBIc_ACTIVE(imp_dbh)) {
        /* Either an explicit disconnect() or global destruction        */
        /* has disconnected us from the database. Finish is meaningless */
        DBIc_ACTIVE_off(imp_sth);
        XSRETURN_YES;
    }
#ifdef dbd_st_finish3
    RETVAL = dbd_st_finish3(sth, imp_sth, 0);
#else
    RETVAL = dbd_st_finish(sth, imp_sth);
#endif
#line 2319 "SQLite.c"
	ST(0) = boolSV(RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__st_blob_read); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__st_blob_read)
{
    dVAR; dXSARGS;
    if (items < 4 || items > 6)
       croak_xs_usage(cv,  "sth, field, offset, len, destrv=Nullsv, destoffset=0");
    {
	SV *	sth = ST(0)
;
	int	field = (int)SvIV(ST(1))
;
	long	offset = (long)SvIV(ST(2))
;
	long	len = (long)SvIV(ST(3))
;
	SV *	destrv;
	long	destoffset;

	if (items < 5)
	    destrv = Nullsv;
	else {
	    destrv = ST(4)
;
	}

	if (items < 6)
	    destoffset = 0;
	else {
	    destoffset = (long)SvIV(ST(5))
;
	}
#line 773 "./SQLite.xsi"
    {
    D_imp_sth(sth);
    if (!destrv)
        destrv = sv_2mortal(newRV(sv_2mortal(newSV(0))));
    if (dbd_st_blob_read(sth, imp_sth, field, offset, len, destrv, destoffset))
         ST(0) = SvRV(destrv);
    else ST(0) = &PL_sv_undef;
    }
#line 2366 "SQLite.c"
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__st_STORE); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__st_STORE)
{
    dVAR; dXSARGS;
    if (items != 3)
       croak_xs_usage(cv,  "sth, keysv, valuesv");
    {
	SV *	sth = ST(0)
;
	SV *	keysv = ST(1)
;
	SV *	valuesv = ST(2)
;
#line 789 "./SQLite.xsi"
    D_imp_sth(sth);
    if (SvGMAGICAL(valuesv))
        mg_get(valuesv);
    ST(0) = &PL_sv_yes;
    if (!dbd_st_STORE_attrib(sth, imp_sth, keysv, valuesv))
        if (!DBIc_DBISTATE(imp_sth)->set_attr(sth, keysv, valuesv))
            ST(0) = &PL_sv_no;
#line 2393 "SQLite.c"
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__st_FETCH_attrib); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__st_FETCH_attrib)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 2)
       croak_xs_usage(cv,  "sth, keysv");
    {
	SV *	sth = ST(0)
;
	SV *	keysv = ST(1)
;
#line 806 "./SQLite.xsi"
    D_imp_sth(sth);
    SV *valuesv;
    PERL_UNUSED_VAR(ix);
    valuesv = dbd_st_FETCH_attrib(sth, imp_sth, keysv);
    if (!valuesv)
        valuesv = DBIc_DBISTATE(imp_sth)->get_attr(sth, keysv);
    ST(0) = valuesv;    /* dbd_st_FETCH_attrib did sv_2mortal   */
#line 2419 "SQLite.c"
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__st_DESTROY); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__st_DESTROY)
{
    dVAR; dXSARGS;
    if (items != 1)
       croak_xs_usage(cv,  "sth");
    PERL_UNUSED_VAR(ax); /* -Wall */
    SP -= items;
    {
	SV *	sth = ST(0)
;
#line 819 "./SQLite.xsi"
    /* keep in sync with default DESTROY in DBI.xs */
    D_imp_sth(sth);
    ST(0) = &PL_sv_yes;
    if (!DBIc_IMPSET(imp_sth)) {        /* was never fully set up       */
        STRLEN lna;
        if (DBIc_WARN(imp_sth) && !PL_dirty && DBIc_DBISTATE(imp_sth)->debug >= 2)
             PerlIO_printf(DBIc_LOGPIO(imp_sth),
                "         DESTROY for %s ignored - handle not initialised\n",
                    SvPV(sth,lna));
    }
    else {
        if (DBIc_IADESTROY(imp_sth)) {  /* wants ineffective destroy    */
            DBIc_ACTIVE_off(imp_sth);
            if (DBIc_DBISTATE(imp_sth)->debug)
                 PerlIO_printf(DBIc_LOGPIO(imp_sth), "         DESTROY %s skipped due to InactiveDestroy\n", SvPV_nolen(sth));
        }
        if (DBIc_ACTIVE(imp_sth)) {
            D_imp_dbh_from_sth;
            if (!PL_dirty && DBIc_ACTIVE(imp_dbh)) {
#ifdef dbd_st_finish3
                dbd_st_finish3(sth, imp_sth, 1);
#else
                dbd_st_finish(sth, imp_sth);
#endif
            }
            else {
                DBIc_ACTIVE_off(imp_sth);
            }
        }
        dbd_st_destroy(sth, imp_sth);
    }
#line 2468 "SQLite.c"
	PUTBACK;
	return;
    }
}


/* INCLUDE: Returning to 'constants.inc' from 'SQLite.xsi' */

#if SQLITE_VERSION_NUMBER >= 3034000
#define XSubPPtmpAAAM 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_allowed_return_values_from_sqlite3_txn_state_3034000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_allowed_return_values_from_sqlite3_txn_state_3034000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 24 "./constants.inc"
        RETVAL = ix;
#line 2493 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAAN 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_allowed_return_values_from_sqlite3_txn_state_3034000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_allowed_return_values_from_sqlite3_txn_state_3034000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 37 "./constants.inc"
        RETVAL = 0;
#line 2516 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_DBD__SQLite__Constants__const_authorizer_action_codes); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_authorizer_action_codes)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 79 "./constants.inc"
        RETVAL = ix;
#line 2537 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if SQLITE_VERSION_NUMBER >= 3006008
#define XSubPPtmpAAAO 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_authorizer_action_codes_3006008); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_authorizer_action_codes_3006008)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 90 "./constants.inc"
        RETVAL = ix;
#line 2560 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAAP 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_authorizer_action_codes_3006008_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_authorizer_action_codes_3006008_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 101 "./constants.inc"
        RETVAL = 0;
#line 2583 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3008003
#define XSubPPtmpAAAQ 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_authorizer_action_codes_3008003); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_authorizer_action_codes_3008003)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 114 "./constants.inc"
        RETVAL = ix;
#line 2607 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAAR 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_authorizer_action_codes_3008003_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_authorizer_action_codes_3008003_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 125 "./constants.inc"
        RETVAL = 0;
#line 2630 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_DBD__SQLite__Constants__const_authorizer_return_codes); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_authorizer_return_codes)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 137 "./constants.inc"
        RETVAL = ix;
#line 2651 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__Constants__const_compile_time_library_version_numbers); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_compile_time_library_version_numbers)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 146 "./constants.inc"
        RETVAL = ix;
#line 2671 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if SQLITE_VERSION_NUMBER >= 3007000
#define XSubPPtmpAAAS 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3007000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3007000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 157 "./constants.inc"
        RETVAL = ix;
#line 2694 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAAT 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3007000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3007000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 168 "./constants.inc"
        RETVAL = 0;
#line 2717 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3007006
#define XSubPPtmpAAAU 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3007006); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3007006)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 182 "./constants.inc"
        RETVAL = ix;
#line 2741 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAAV 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3007006_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3007006_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 194 "./constants.inc"
        RETVAL = 0;
#line 2764 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3012002
#define XSubPPtmpAAAW 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3012002); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3012002)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 207 "./constants.inc"
        RETVAL = ix;
#line 2788 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAAX 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3012002_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3012002_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 218 "./constants.inc"
        RETVAL = 0;
#line 2811 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3013000
#define XSubPPtmpAAAY 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3013000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3013000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 231 "./constants.inc"
        RETVAL = ix;
#line 2835 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAAZ 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3013000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3013000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 242 "./constants.inc"
        RETVAL = 0;
#line 2858 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3015000
#define XSubPPtmpAABA 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3015000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3015000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 255 "./constants.inc"
        RETVAL = ix;
#line 2882 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAABB 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3015000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3015000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 266 "./constants.inc"
        RETVAL = 0;
#line 2905 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3016000
#define XSubPPtmpAABC 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3016000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3016000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 279 "./constants.inc"
        RETVAL = ix;
#line 2929 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAABD 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3016000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3016000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 290 "./constants.inc"
        RETVAL = 0;
#line 2952 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3020000
#define XSubPPtmpAABE 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3020000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3020000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 303 "./constants.inc"
        RETVAL = ix;
#line 2976 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAABF 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3020000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3020000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 314 "./constants.inc"
        RETVAL = 0;
#line 2999 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3022000
#define XSubPPtmpAABG 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3022000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3022000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 328 "./constants.inc"
        RETVAL = ix;
#line 3023 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAABH 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3022000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3022000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 340 "./constants.inc"
        RETVAL = 0;
#line 3046 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3024000
#define XSubPPtmpAABI 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3024000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3024000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 353 "./constants.inc"
        RETVAL = ix;
#line 3070 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAABJ 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3024000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3024000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 364 "./constants.inc"
        RETVAL = 0;
#line 3093 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3026000
#define XSubPPtmpAABK 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3026000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3026000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 377 "./constants.inc"
        RETVAL = ix;
#line 3117 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAABL 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3026000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3026000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 388 "./constants.inc"
        RETVAL = 0;
#line 3140 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3028000
#define XSubPPtmpAABM 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3028000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3028000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 401 "./constants.inc"
        RETVAL = ix;
#line 3164 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAABN 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3028000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3028000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 412 "./constants.inc"
        RETVAL = 0;
#line 3187 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3029000
#define XSubPPtmpAABO 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3029000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3029000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 427 "./constants.inc"
        RETVAL = ix;
#line 3211 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAABP 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3029000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3029000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 440 "./constants.inc"
        RETVAL = 0;
#line 3234 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3030000
#define XSubPPtmpAABQ 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3030000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3030000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 453 "./constants.inc"
        RETVAL = ix;
#line 3258 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAABR 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3030000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3030000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 464 "./constants.inc"
        RETVAL = 0;
#line 3281 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3031000
#define XSubPPtmpAABS 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3031000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3031000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 478 "./constants.inc"
        RETVAL = ix;
#line 3305 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAABT 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3031000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3031000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 490 "./constants.inc"
        RETVAL = 0;
#line 3328 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3042000
#define XSubPPtmpAABU 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3042000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3042000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 504 "./constants.inc"
        RETVAL = ix;
#line 3352 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAABV 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3042000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3042000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 516 "./constants.inc"
        RETVAL = 0;
#line 3375 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3049000
#define XSubPPtmpAABW 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3049000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3049000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 531 "./constants.inc"
        RETVAL = ix;
#line 3399 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAABX 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3049000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3049000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 544 "./constants.inc"
        RETVAL = 0;
#line 3422 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3006002
#define XSubPPtmpAABY 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3006002); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3006002)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 557 "./constants.inc"
        RETVAL = ix;
#line 3446 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAABZ 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3006002_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3006002_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 568 "./constants.inc"
        RETVAL = 0;
#line 3469 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3006005
#define XSubPPtmpAACA 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3006005); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3006005)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 594 "./constants.inc"
        RETVAL = ix;
#line 3493 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAACB 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3006005_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3006005_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 618 "./constants.inc"
        RETVAL = 0;
#line 3516 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3006007
#define XSubPPtmpAACC 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3006007); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3006007)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 632 "./constants.inc"
        RETVAL = ix;
#line 3540 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAACD 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3006007_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3006007_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 644 "./constants.inc"
        RETVAL = 0;
#line 3563 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3006012
#define XSubPPtmpAACE 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3006012); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3006012)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 657 "./constants.inc"
        RETVAL = ix;
#line 3587 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAACF 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3006012_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3006012_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 668 "./constants.inc"
        RETVAL = 0;
#line 3610 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3007000
#define XSubPPtmpAACG 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3007000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3007000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 685 "./constants.inc"
        RETVAL = ix;
#line 3634 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAACH 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3007000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3007000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 700 "./constants.inc"
        RETVAL = 0;
#line 3657 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3007007
#define XSubPPtmpAACI 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3007007); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3007007)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 717 "./constants.inc"
        RETVAL = ix;
#line 3681 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAACJ 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3007007_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3007007_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 732 "./constants.inc"
        RETVAL = 0;
#line 3704 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3007011
#define XSubPPtmpAACK 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3007011); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3007011)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 745 "./constants.inc"
        RETVAL = ix;
#line 3728 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAACL 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3007011_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3007011_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 756 "./constants.inc"
        RETVAL = 0;
#line 3751 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3007012
#define XSubPPtmpAACM 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3007012); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3007012)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 769 "./constants.inc"
        RETVAL = ix;
#line 3775 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAACN 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3007012_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3007012_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 780 "./constants.inc"
        RETVAL = 0;
#line 3798 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3007015
#define XSubPPtmpAACO 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3007015); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3007015)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 794 "./constants.inc"
        RETVAL = ix;
#line 3822 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAACP 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3007015_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3007015_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 806 "./constants.inc"
        RETVAL = 0;
#line 3845 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3007016
#define XSubPPtmpAACQ 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3007016); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3007016)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 828 "./constants.inc"
        RETVAL = ix;
#line 3869 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAACR 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3007016_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3007016_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 848 "./constants.inc"
        RETVAL = 0;
#line 3892 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3007017
#define XSubPPtmpAACS 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3007017); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3007017)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 863 "./constants.inc"
        RETVAL = ix;
#line 3916 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAACT 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3007017_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3007017_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 876 "./constants.inc"
        RETVAL = 0;
#line 3939 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3008000
#define XSubPPtmpAACU 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3008000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3008000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 891 "./constants.inc"
        RETVAL = ix;
#line 3963 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAACV 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3008000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3008000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 904 "./constants.inc"
        RETVAL = 0;
#line 3986 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3008001
#define XSubPPtmpAACW 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3008001); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3008001)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 918 "./constants.inc"
        RETVAL = ix;
#line 4010 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAACX 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3008001_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3008001_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 930 "./constants.inc"
        RETVAL = 0;
#line 4033 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3008002
#define XSubPPtmpAACY 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3008002); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3008002)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 943 "./constants.inc"
        RETVAL = ix;
#line 4057 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAACZ 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3008002_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3008002_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 954 "./constants.inc"
        RETVAL = 0;
#line 4080 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3008003
#define XSubPPtmpAADA 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3008003); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3008003)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 967 "./constants.inc"
        RETVAL = ix;
#line 4104 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAADB 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3008003_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3008003_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 978 "./constants.inc"
        RETVAL = 0;
#line 4127 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3008007
#define XSubPPtmpAADC 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3008007); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3008007)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 991 "./constants.inc"
        RETVAL = ix;
#line 4151 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAADD 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3008007_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3008007_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1002 "./constants.inc"
        RETVAL = 0;
#line 4174 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3009000
#define XSubPPtmpAADE 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3009000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3009000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1015 "./constants.inc"
        RETVAL = ix;
#line 4198 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAADF 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3009000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3009000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1026 "./constants.inc"
        RETVAL = 0;
#line 4221 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3010000
#define XSubPPtmpAADG 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3010000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3010000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1039 "./constants.inc"
        RETVAL = ix;
#line 4245 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAADH 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3010000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3010000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1050 "./constants.inc"
        RETVAL = 0;
#line 4268 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3021000
#define XSubPPtmpAADI 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3021000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3021000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1065 "./constants.inc"
        RETVAL = ix;
#line 4292 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAADJ 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3021000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3021000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1078 "./constants.inc"
        RETVAL = 0;
#line 4315 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3022000
#define XSubPPtmpAADK 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3022000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3022000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1094 "./constants.inc"
        RETVAL = ix;
#line 4339 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAADL 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3022000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3022000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1108 "./constants.inc"
        RETVAL = 0;
#line 4362 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3024000
#define XSubPPtmpAADM 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3024000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3024000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1122 "./constants.inc"
        RETVAL = ix;
#line 4386 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAADN 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3024000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3024000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1134 "./constants.inc"
        RETVAL = 0;
#line 4409 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3025000
#define XSubPPtmpAADO 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3025000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3025000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1148 "./constants.inc"
        RETVAL = ix;
#line 4433 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAADP 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3025000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3025000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1160 "./constants.inc"
        RETVAL = 0;
#line 4456 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3031000
#define XSubPPtmpAADQ 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3031000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3031000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1175 "./constants.inc"
        RETVAL = ix;
#line 4480 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAADR 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3031000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3031000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1188 "./constants.inc"
        RETVAL = 0;
#line 4503 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3032000
#define XSubPPtmpAADS 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3032000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3032000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1203 "./constants.inc"
        RETVAL = ix;
#line 4527 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAADT 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3032000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3032000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1216 "./constants.inc"
        RETVAL = 0;
#line 4550 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3034000
#define XSubPPtmpAADU 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3034000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3034000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1229 "./constants.inc"
        RETVAL = ix;
#line 4574 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAADV 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3034000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3034000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1240 "./constants.inc"
        RETVAL = 0;
#line 4597 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3037000
#define XSubPPtmpAADW 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3037000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3037000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1253 "./constants.inc"
        RETVAL = ix;
#line 4621 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAADX 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3037000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3037000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1264 "./constants.inc"
        RETVAL = 0;
#line 4644 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3041000
#define XSubPPtmpAADY 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3041000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3041000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1277 "./constants.inc"
        RETVAL = ix;
#line 4668 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAADZ 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3041000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3041000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1288 "./constants.inc"
        RETVAL = 0;
#line 4691 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3043000
#define XSubPPtmpAAEA 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3043000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3043000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1301 "./constants.inc"
        RETVAL = ix;
#line 4715 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAEB 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3043000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3043000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1312 "./constants.inc"
        RETVAL = 0;
#line 4738 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3051000
#define XSubPPtmpAAEC 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3051000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3051000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1329 "./constants.inc"
        RETVAL = ix;
#line 4762 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAED 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3051000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_extended_result_codes_3051000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1344 "./constants.inc"
        RETVAL = 0;
#line 4785 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_DBD__SQLite__Constants__const_flags_for_file_open_operations); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_flags_for_file_open_operations)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1358 "./constants.inc"
        RETVAL = ix;
#line 4806 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if SQLITE_VERSION_NUMBER >= 3006002
#define XSubPPtmpAAEE 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3006002); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3006002)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1369 "./constants.inc"
        RETVAL = ix;
#line 4829 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAEF 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3006002_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3006002_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1380 "./constants.inc"
        RETVAL = 0;
#line 4852 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3006018
#define XSubPPtmpAAEG 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3006018); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3006018)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1394 "./constants.inc"
        RETVAL = ix;
#line 4876 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAEH 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3006018_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3006018_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1406 "./constants.inc"
        RETVAL = 0;
#line 4899 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3007007
#define XSubPPtmpAAEI 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3007007); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3007007)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1419 "./constants.inc"
        RETVAL = ix;
#line 4923 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAEJ 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3007007_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3007007_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1430 "./constants.inc"
        RETVAL = 0;
#line 4946 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3007013
#define XSubPPtmpAAEK 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3007013); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3007013)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1443 "./constants.inc"
        RETVAL = ix;
#line 4970 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAEL 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3007013_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3007013_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1454 "./constants.inc"
        RETVAL = 0;
#line 4993 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3031000
#define XSubPPtmpAAEM 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3031000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3031000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1467 "./constants.inc"
        RETVAL = ix;
#line 5017 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAEN 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3031000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3031000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1478 "./constants.inc"
        RETVAL = 0;
#line 5040 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3033000
#define XSubPPtmpAAEO 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3033000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3033000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1491 "./constants.inc"
        RETVAL = ix;
#line 5064 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAEP 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3033000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3033000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1502 "./constants.inc"
        RETVAL = 0;
#line 5087 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3037000
#define XSubPPtmpAAEQ 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3037000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3037000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1515 "./constants.inc"
        RETVAL = ix;
#line 5111 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAER 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3037000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3037000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1526 "./constants.inc"
        RETVAL = 0;
#line 5134 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3050000
#define XSubPPtmpAAES 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_flags_for_sqlite3_setlk_timeout_3050000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_flags_for_sqlite3_setlk_timeout_3050000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1539 "./constants.inc"
        RETVAL = ix;
#line 5158 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAET 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_flags_for_sqlite3_setlk_timeout_3050000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_flags_for_sqlite3_setlk_timeout_3050000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1550 "./constants.inc"
        RETVAL = 0;
#line 5181 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3008003
#define XSubPPtmpAAEU 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_function_flags_3008003); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_function_flags_3008003)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1563 "./constants.inc"
        RETVAL = ix;
#line 5205 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAEV 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_function_flags_3008003_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_function_flags_3008003_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1574 "./constants.inc"
        RETVAL = 0;
#line 5228 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3030000
#define XSubPPtmpAAEW 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_function_flags_3030000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_function_flags_3030000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1588 "./constants.inc"
        RETVAL = ix;
#line 5252 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAEX 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_function_flags_3030000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_function_flags_3030000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1600 "./constants.inc"
        RETVAL = 0;
#line 5275 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3031000
#define XSubPPtmpAAEY 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_function_flags_3031000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_function_flags_3031000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1613 "./constants.inc"
        RETVAL = ix;
#line 5299 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAEZ 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_function_flags_3031000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_function_flags_3031000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1624 "./constants.inc"
        RETVAL = 0;
#line 5322 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3044001
#define XSubPPtmpAAFA 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_function_flags_3044001); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_function_flags_3044001)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1637 "./constants.inc"
        RETVAL = ix;
#line 5346 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAFB 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_function_flags_3044001_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_function_flags_3044001_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1648 "./constants.inc"
        RETVAL = 0;
#line 5369 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3047000
#define XSubPPtmpAAFC 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_function_flags_3047000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_function_flags_3047000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1661 "./constants.inc"
        RETVAL = ix;
#line 5393 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAFD 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_function_flags_3047000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_function_flags_3047000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1672 "./constants.inc"
        RETVAL = 0;
#line 5416 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_DBD__SQLite__Constants__const_fundamental_datatypes); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_fundamental_datatypes)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1687 "./constants.inc"
        RETVAL = ix;
#line 5437 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__Constants__const_result_codes); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_result_codes)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1724 "./constants.inc"
        RETVAL = ix;
#line 5457 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if SQLITE_VERSION_NUMBER >= 3007017
#define XSubPPtmpAAFE 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_result_codes_3007017); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_result_codes_3007017)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1736 "./constants.inc"
        RETVAL = ix;
#line 5480 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAFF 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_result_codes_3007017_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_result_codes_3007017_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1748 "./constants.inc"
        RETVAL = 0;
#line 5503 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_DBD__SQLite__Constants__const_run_time_limit_categories); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_run_time_limit_categories)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1768 "./constants.inc"
        RETVAL = ix;
#line 5524 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if SQLITE_VERSION_NUMBER >= 3006018
#define XSubPPtmpAAFG 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_run_time_limit_categories_3006018); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_run_time_limit_categories_3006018)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1779 "./constants.inc"
        RETVAL = ix;
#line 5547 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAFH 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_run_time_limit_categories_3006018_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_run_time_limit_categories_3006018_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1790 "./constants.inc"
        RETVAL = 0;
#line 5570 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3008007
#define XSubPPtmpAAFI 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_run_time_limit_categories_3008007); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_run_time_limit_categories_3008007)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1803 "./constants.inc"
        RETVAL = ix;
#line 5594 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAFJ 1


XS_EUPXS(XS_DBD__SQLite__Constants__const_run_time_limit_categories_3008007_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__Constants__const_run_time_limit_categories_3008007_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1814 "./constants.inc"
        RETVAL = 0;
#line 5617 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_DBD__SQLite__const__authorizer_action_codes); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__const__authorizer_action_codes)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1862 "./constants.inc"
        RETVAL = ix;
#line 5638 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if SQLITE_VERSION_NUMBER >= 3006008
#define XSubPPtmpAAFK 1


XS_EUPXS(XS_DBD__SQLite__const__authorizer_action_codes_3006008); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__const__authorizer_action_codes_3006008)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1873 "./constants.inc"
        RETVAL = ix;
#line 5661 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAFL 1


XS_EUPXS(XS_DBD__SQLite__const__authorizer_action_codes_3006008_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__const__authorizer_action_codes_3006008_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1884 "./constants.inc"
        RETVAL = 0;
#line 5684 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3008003
#define XSubPPtmpAAFM 1


XS_EUPXS(XS_DBD__SQLite__const__authorizer_action_codes_3008003); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__const__authorizer_action_codes_3008003)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1897 "./constants.inc"
        RETVAL = ix;
#line 5708 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAFN 1


XS_EUPXS(XS_DBD__SQLite__const__authorizer_action_codes_3008003_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__const__authorizer_action_codes_3008003_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1908 "./constants.inc"
        RETVAL = 0;
#line 5731 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

XS_EUPXS(XS_DBD__SQLite__const__authorizer_return_codes); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__const__authorizer_return_codes)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1921 "./constants.inc"
        RETVAL = ix;
#line 5752 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}


XS_EUPXS(XS_DBD__SQLite__const__flags_for_file_open_operations); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__const__flags_for_file_open_operations)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1933 "./constants.inc"
        RETVAL = ix;
#line 5772 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#if SQLITE_VERSION_NUMBER >= 3006002
#define XSubPPtmpAAFO 1


XS_EUPXS(XS_DBD__SQLite__const__flags_for_file_open_operations_3006002); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__const__flags_for_file_open_operations_3006002)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1944 "./constants.inc"
        RETVAL = ix;
#line 5795 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAFP 1


XS_EUPXS(XS_DBD__SQLite__const__flags_for_file_open_operations_3006002_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__const__flags_for_file_open_operations_3006002_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1955 "./constants.inc"
        RETVAL = 0;
#line 5818 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3006018
#define XSubPPtmpAAFQ 1


XS_EUPXS(XS_DBD__SQLite__const__flags_for_file_open_operations_3006018); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__const__flags_for_file_open_operations_3006018)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1969 "./constants.inc"
        RETVAL = ix;
#line 5842 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAFR 1


XS_EUPXS(XS_DBD__SQLite__const__flags_for_file_open_operations_3006018_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__const__flags_for_file_open_operations_3006018_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1981 "./constants.inc"
        RETVAL = 0;
#line 5865 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3007007
#define XSubPPtmpAAFS 1


XS_EUPXS(XS_DBD__SQLite__const__flags_for_file_open_operations_3007007); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__const__flags_for_file_open_operations_3007007)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 1994 "./constants.inc"
        RETVAL = ix;
#line 5889 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAFT 1


XS_EUPXS(XS_DBD__SQLite__const__flags_for_file_open_operations_3007007_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__const__flags_for_file_open_operations_3007007_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 2005 "./constants.inc"
        RETVAL = 0;
#line 5912 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3007013
#define XSubPPtmpAAFU 1


XS_EUPXS(XS_DBD__SQLite__const__flags_for_file_open_operations_3007013); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__const__flags_for_file_open_operations_3007013)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 2018 "./constants.inc"
        RETVAL = ix;
#line 5936 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAFV 1


XS_EUPXS(XS_DBD__SQLite__const__flags_for_file_open_operations_3007013_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__const__flags_for_file_open_operations_3007013_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 2029 "./constants.inc"
        RETVAL = 0;
#line 5959 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3031000
#define XSubPPtmpAAFW 1


XS_EUPXS(XS_DBD__SQLite__const__flags_for_file_open_operations_3031000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__const__flags_for_file_open_operations_3031000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 2042 "./constants.inc"
        RETVAL = ix;
#line 5983 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAFX 1


XS_EUPXS(XS_DBD__SQLite__const__flags_for_file_open_operations_3031000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__const__flags_for_file_open_operations_3031000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 2053 "./constants.inc"
        RETVAL = 0;
#line 6006 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3033000
#define XSubPPtmpAAFY 1


XS_EUPXS(XS_DBD__SQLite__const__flags_for_file_open_operations_3033000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__const__flags_for_file_open_operations_3033000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 2066 "./constants.inc"
        RETVAL = ix;
#line 6030 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAFZ 1


XS_EUPXS(XS_DBD__SQLite__const__flags_for_file_open_operations_3033000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__const__flags_for_file_open_operations_3033000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 2077 "./constants.inc"
        RETVAL = 0;
#line 6053 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif
#if SQLITE_VERSION_NUMBER >= 3037000
#define XSubPPtmpAAGA 1


XS_EUPXS(XS_DBD__SQLite__const__flags_for_file_open_operations_3037000); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__const__flags_for_file_open_operations_3037000)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 2090 "./constants.inc"
        RETVAL = ix;
#line 6077 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#else
#define XSubPPtmpAAGB 1


XS_EUPXS(XS_DBD__SQLite__const__flags_for_file_open_operations_3037000_zero); /* prototype to pass -Wmissing-prototypes */
XS_EUPXS(XS_DBD__SQLite__const__flags_for_file_open_operations_3037000_zero)
{
    dVAR; dXSARGS;
    dXSI32;
    if (items != 0)
       croak_xs_usage(cv,  "");
    {
	IV	RETVAL;
	dXSTARG;
#line 2101 "./constants.inc"
        RETVAL = 0;
#line 6100 "SQLite.c"
	XSprePUSH;
	PUSHi((IV)RETVAL);
    }
    XSRETURN(1);
}

#endif

/* INCLUDE: Returning to 'SQLite.xs' from 'constants.inc' */

#ifdef __cplusplus
extern "C" {
#endif
XS_EXTERNAL(boot_DBD__SQLite); /* prototype to pass -Wmissing-prototypes */
XS_EXTERNAL(boot_DBD__SQLite)
{
#if PERL_VERSION_LE(5, 21, 5)
    dVAR; dXSARGS;
#else
    dVAR; dXSBOOTARGSXSAPIVERCHK;
#endif
#if PERL_VERSION_LE(5, 8, 999) /* PERL_VERSION_LT is 5.33+ */
    char* file = __FILE__;
#else
    const char* file = __FILE__;
#endif

    PERL_UNUSED_VAR(file);

    PERL_UNUSED_VAR(cv); /* -W */
    PERL_UNUSED_VAR(items); /* -W */
#if PERL_VERSION_LE(5, 21, 5)
    XS_VERSION_BOOTCHECK;
#  ifdef XS_APIVERSION_BOOTCHECK
    XS_APIVERSION_BOOTCHECK;
#  endif
#endif

    {
        CV * cv;

        newXS_deffile("DBD::SQLite::db::_do", XS_DBD__SQLite__db__do);
        cv = newXS_deffile("DBD::SQLite::db::last_insert_rowid", XS_DBD__SQLite__db_last_insert_rowid);
        XSANY.any_i32 = 0;
        cv = newXS_deffile("DBD::SQLite::db::sqlite_last_insert_rowid", XS_DBD__SQLite__db_last_insert_rowid);
        XSANY.any_i32 = 1;
        cv = newXS_deffile("DBD::SQLite::db::create_function", XS_DBD__SQLite__db_create_function);
        XSANY.any_i32 = 0;
        cv = newXS_deffile("DBD::SQLite::db::sqlite_create_function", XS_DBD__SQLite__db_create_function);
        XSANY.any_i32 = 1;
#if XSubPPtmpAAAA
        cv = newXS_deffile("DBD::SQLite::db::enable_load_extension", XS_DBD__SQLite__db_enable_load_extension);
        XSANY.any_i32 = 0;
        cv = newXS_deffile("DBD::SQLite::db::sqlite_enable_load_extension", XS_DBD__SQLite__db_enable_load_extension);
        XSANY.any_i32 = 1;
        cv = newXS_deffile("DBD::SQLite::db::load_extension", XS_DBD__SQLite__db_load_extension);
        XSANY.any_i32 = 0;
        cv = newXS_deffile("DBD::SQLite::db::sqlite_load_extension", XS_DBD__SQLite__db_load_extension);
        XSANY.any_i32 = 1;
#endif
        cv = newXS_deffile("DBD::SQLite::db::create_aggregate", XS_DBD__SQLite__db_create_aggregate);
        XSANY.any_i32 = 0;
        cv = newXS_deffile("DBD::SQLite::db::sqlite_create_aggregate", XS_DBD__SQLite__db_create_aggregate);
        XSANY.any_i32 = 1;
        cv = newXS_deffile("DBD::SQLite::db::create_collation", XS_DBD__SQLite__db_create_collation);
        XSANY.any_i32 = 0;
        cv = newXS_deffile("DBD::SQLite::db::sqlite_create_collation", XS_DBD__SQLite__db_create_collation);
        XSANY.any_i32 = 1;
        cv = newXS_deffile("DBD::SQLite::db::collation_needed", XS_DBD__SQLite__db_collation_needed);
        XSANY.any_i32 = 0;
        cv = newXS_deffile("DBD::SQLite::db::sqlite_collation_needed", XS_DBD__SQLite__db_collation_needed);
        XSANY.any_i32 = 1;
        cv = newXS_deffile("DBD::SQLite::db::progress_handler", XS_DBD__SQLite__db_progress_handler);
        XSANY.any_i32 = 0;
        cv = newXS_deffile("DBD::SQLite::db::sqlite_progress_handler", XS_DBD__SQLite__db_progress_handler);
        XSANY.any_i32 = 1;
        newXS_deffile("DBD::SQLite::db::sqlite_trace", XS_DBD__SQLite__db_sqlite_trace);
        cv = newXS_deffile("DBD::SQLite::db::profile", XS_DBD__SQLite__db_profile);
        XSANY.any_i32 = 0;
        cv = newXS_deffile("DBD::SQLite::db::sqlite_profile", XS_DBD__SQLite__db_profile);
        XSANY.any_i32 = 1;
        cv = newXS_deffile("DBD::SQLite::db::commit_hook", XS_DBD__SQLite__db_commit_hook);
        XSANY.any_i32 = 0;
        cv = newXS_deffile("DBD::SQLite::db::sqlite_commit_hook", XS_DBD__SQLite__db_commit_hook);
        XSANY.any_i32 = 1;
        cv = newXS_deffile("DBD::SQLite::db::rollback_hook", XS_DBD__SQLite__db_rollback_hook);
        XSANY.any_i32 = 0;
        cv = newXS_deffile("DBD::SQLite::db::sqlite_rollback_hook", XS_DBD__SQLite__db_rollback_hook);
        XSANY.any_i32 = 1;
        cv = newXS_deffile("DBD::SQLite::db::sqlite_update_hook", XS_DBD__SQLite__db_update_hook);
        XSANY.any_i32 = 1;
        cv = newXS_deffile("DBD::SQLite::db::update_hook", XS_DBD__SQLite__db_update_hook);
        XSANY.any_i32 = 0;
        cv = newXS_deffile("DBD::SQLite::db::set_authorizer", XS_DBD__SQLite__db_set_authorizer);
        XSANY.any_i32 = 0;
        cv = newXS_deffile("DBD::SQLite::db::sqlite_set_authorizer", XS_DBD__SQLite__db_set_authorizer);
        XSANY.any_i32 = 1;
        cv = newXS_deffile("DBD::SQLite::db::busy_timeout", XS_DBD__SQLite__db_busy_timeout);
        XSANY.any_i32 = 0;
        cv = newXS_deffile("DBD::SQLite::db::sqlite_busy_timeout", XS_DBD__SQLite__db_busy_timeout);
        XSANY.any_i32 = 1;
        cv = newXS_deffile("DBD::SQLite::db::backup_from_file", XS_DBD__SQLite__db_backup_from_file);
        XSANY.any_i32 = 0;
        cv = newXS_deffile("DBD::SQLite::db::sqlite_backup_from_file", XS_DBD__SQLite__db_backup_from_file);
        XSANY.any_i32 = 1;
        cv = newXS_deffile("DBD::SQLite::db::backup_to_file", XS_DBD__SQLite__db_backup_to_file);
        XSANY.any_i32 = 0;
        cv = newXS_deffile("DBD::SQLite::db::sqlite_backup_to_file", XS_DBD__SQLite__db_backup_to_file);
        XSANY.any_i32 = 1;
        cv = newXS_deffile("DBD::SQLite::db::backup_from_dbh", XS_DBD__SQLite__db_backup_from_dbh);
        XSANY.any_i32 = 0;
        cv = newXS_deffile("DBD::SQLite::db::sqlite_backup_from_dbh", XS_DBD__SQLite__db_backup_from_dbh);
        XSANY.any_i32 = 1;
        cv = newXS_deffile("DBD::SQLite::db::backup_to_dbh", XS_DBD__SQLite__db_backup_to_dbh);
        XSANY.any_i32 = 0;
        cv = newXS_deffile("DBD::SQLite::db::sqlite_backup_to_dbh", XS_DBD__SQLite__db_backup_to_dbh);
        XSANY.any_i32 = 1;
        cv = newXS_deffile("DBD::SQLite::db::sqlite_table_column_metadata", XS_DBD__SQLite__db_table_column_metadata);
        XSANY.any_i32 = 1;
        cv = newXS_deffile("DBD::SQLite::db::table_column_metadata", XS_DBD__SQLite__db_table_column_metadata);
        XSANY.any_i32 = 0;
        cv = newXS_deffile("DBD::SQLite::db::db_filename", XS_DBD__SQLite__db_db_filename);
        XSANY.any_i32 = 0;
        cv = newXS_deffile("DBD::SQLite::db::sqlite_db_filename", XS_DBD__SQLite__db_db_filename);
        XSANY.any_i32 = 1;
        cv = newXS_deffile("DBD::SQLite::db::register_fts3_perl_tokenizer", XS_DBD__SQLite__db_register_fts3_perl_tokenizer);
        XSANY.any_i32 = 0;
        cv = newXS_deffile("DBD::SQLite::db::sqlite_register_fts3_perl_tokenizer", XS_DBD__SQLite__db_register_fts3_perl_tokenizer);
        XSANY.any_i32 = 1;
        cv = newXS_deffile("DBD::SQLite::db::db_status", XS_DBD__SQLite__db_db_status);
        XSANY.any_i32 = 0;
        cv = newXS_deffile("DBD::SQLite::db::sqlite_db_status", XS_DBD__SQLite__db_db_status);
        XSANY.any_i32 = 1;
        cv = newXS_deffile("DBD::SQLite::db::create_module", XS_DBD__SQLite__db_create_module);
        XSANY.any_i32 = 0;
        cv = newXS_deffile("DBD::SQLite::db::sqlite_create_module", XS_DBD__SQLite__db_create_module);
        XSANY.any_i32 = 1;
        cv = newXS_deffile("DBD::SQLite::db::limit", XS_DBD__SQLite__db_limit);
        XSANY.any_i32 = 0;
        cv = newXS_deffile("DBD::SQLite::db::sqlite_limit", XS_DBD__SQLite__db_limit);
        XSANY.any_i32 = 1;
        cv = newXS_deffile("DBD::SQLite::db::db_config", XS_DBD__SQLite__db_db_config);
        XSANY.any_i32 = 0;
        cv = newXS_deffile("DBD::SQLite::db::sqlite_db_config", XS_DBD__SQLite__db_db_config);
        XSANY.any_i32 = 1;
        cv = newXS_deffile("DBD::SQLite::db::get_autocommit", XS_DBD__SQLite__db_get_autocommit);
        XSANY.any_i32 = 0;
        cv = newXS_deffile("DBD::SQLite::db::sqlite_get_autocommit", XS_DBD__SQLite__db_get_autocommit);
        XSANY.any_i32 = 1;
        cv = newXS_deffile("DBD::SQLite::db::sqlite_txn_state", XS_DBD__SQLite__db_txn_state);
        XSANY.any_i32 = 1;
        cv = newXS_deffile("DBD::SQLite::db::txn_state", XS_DBD__SQLite__db_txn_state);
        XSANY.any_i32 = 0;
        cv = newXS_deffile("DBD::SQLite::db::error_offset", XS_DBD__SQLite__db_error_offset);
        XSANY.any_i32 = 0;
        cv = newXS_deffile("DBD::SQLite::db::sqlite_error_offset", XS_DBD__SQLite__db_error_offset);
        XSANY.any_i32 = 1;
        cv = newXS_deffile("DBD::SQLite::st::sqlite_st_status", XS_DBD__SQLite__st_st_status);
        XSANY.any_i32 = 1;
        cv = newXS_deffile("DBD::SQLite::st::st_status", XS_DBD__SQLite__st_st_status);
        XSANY.any_i32 = 0;
        newXS_deffile("DBD::SQLite::compile_options", XS_DBD__SQLite_compile_options);
        newXS_deffile("DBD::SQLite::sqlite_status", XS_DBD__SQLite_sqlite_status);
#if XSubPPtmpAAAB
        newXS_deffile("DBD::SQLite::strglob", XS_DBD__SQLite_strglob);
        newXS_deffile("DBD::SQLite::strlike", XS_DBD__SQLite_strlike);
#endif
        newXS_deffile("DBD::SQLite::dr::dbixs_revision", XS_DBD__SQLite__dr_dbixs_revision);
#if XSubPPtmpAAAC
        cv = newXS_deffile("DBD::SQLite::dr::discon_all_", XS_DBD__SQLite__dr_discon_all_);
        XSANY.any_i32 = 0;
        cv = newXS_deffile("DBD::SQLite::dr::disconnect_all", XS_DBD__SQLite__dr_discon_all_);
        XSANY.any_i32 = 1;
#endif
#if XSubPPtmpAAAD
        newXS_deffile("DBD::SQLite::dr::data_sources", XS_DBD__SQLite__dr_data_sources);
#endif
        newXS_deffile("DBD::SQLite::db::_login", XS_DBD__SQLite__db__login);
        newXS_deffile("DBD::SQLite::db::selectall_arrayref", XS_DBD__SQLite__db_selectall_arrayref);
        cv = newXS_deffile("DBD::SQLite::db::selectrow_array", XS_DBD__SQLite__db_selectrow_arrayref);
        XSANY.any_i32 = 1;
        cv = newXS_deffile("DBD::SQLite::db::selectrow_arrayref", XS_DBD__SQLite__db_selectrow_arrayref);
        XSANY.any_i32 = 0;
#if XSubPPtmpAAAE
        newXS_deffile("DBD::SQLite::db::do", XS_DBD__SQLite__db_do);
#endif
#if XSubPPtmpAAAF
        newXS_deffile("DBD::SQLite::db::last_insert_id", XS_DBD__SQLite__db_last_insert_id);
#endif
        newXS_deffile("DBD::SQLite::db::commit", XS_DBD__SQLite__db_commit);
        newXS_deffile("DBD::SQLite::db::rollback", XS_DBD__SQLite__db_rollback);
        newXS_deffile("DBD::SQLite::db::disconnect", XS_DBD__SQLite__db_disconnect);
        newXS_deffile("DBD::SQLite::db::STORE", XS_DBD__SQLite__db_STORE);
        newXS_deffile("DBD::SQLite::db::FETCH", XS_DBD__SQLite__db_FETCH);
        newXS_deffile("DBD::SQLite::db::DESTROY", XS_DBD__SQLite__db_DESTROY);
#if XSubPPtmpAAAG
        newXS_deffile("DBD::SQLite::db::take_imp_data", XS_DBD__SQLite__db_take_imp_data);
#endif
#if XSubPPtmpAAAH
        newXS_deffile("DBD::SQLite::db::data_sources", XS_DBD__SQLite__db_data_sources);
#endif
        newXS_deffile("DBD::SQLite::st::_prepare", XS_DBD__SQLite__st__prepare);
#if XSubPPtmpAAAI
        newXS_deffile("DBD::SQLite::st::rows", XS_DBD__SQLite__st_rows);
#endif
#if XSubPPtmpAAAJ
        newXS_deffile("DBD::SQLite::st::bind_col", XS_DBD__SQLite__st_bind_col);
#endif
        newXS_deffile("DBD::SQLite::st::bind_param", XS_DBD__SQLite__st_bind_param);
        newXS_deffile("DBD::SQLite::st::bind_param_inout", XS_DBD__SQLite__st_bind_param_inout);
        newXS_deffile("DBD::SQLite::st::execute", XS_DBD__SQLite__st_execute);
#if XSubPPtmpAAAK
        newXS_deffile("DBD::SQLite::st::execute_for_fetch", XS_DBD__SQLite__st_execute_for_fetch);
#endif
#if XSubPPtmpAAAL
        newXS_deffile("DBD::SQLite::st::last_insert_id", XS_DBD__SQLite__st_last_insert_id);
#endif
        cv = newXS_deffile("DBD::SQLite::st::fetch", XS_DBD__SQLite__st_fetchrow_arrayref);
        XSANY.any_i32 = 1;
        cv = newXS_deffile("DBD::SQLite::st::fetchrow_arrayref", XS_DBD__SQLite__st_fetchrow_arrayref);
        XSANY.any_i32 = 0;
        cv = newXS_deffile("DBD::SQLite::st::fetchrow", XS_DBD__SQLite__st_fetchrow_array);
        XSANY.any_i32 = 1;
        cv = newXS_deffile("DBD::SQLite::st::fetchrow_array", XS_DBD__SQLite__st_fetchrow_array);
        XSANY.any_i32 = 0;
        newXS_deffile("DBD::SQLite::st::fetchall_arrayref", XS_DBD__SQLite__st_fetchall_arrayref);
        newXS_deffile("DBD::SQLite::st::finish", XS_DBD__SQLite__st_finish);
        newXS_deffile("DBD::SQLite::st::blob_read", XS_DBD__SQLite__st_blob_read);
        newXS_deffile("DBD::SQLite::st::STORE", XS_DBD__SQLite__st_STORE);
        cv = newXS_deffile("DBD::SQLite::st::FETCH", XS_DBD__SQLite__st_FETCH_attrib);
        XSANY.any_i32 = 1;
        cv = newXS_deffile("DBD::SQLite::st::FETCH_attrib", XS_DBD__SQLite__st_FETCH_attrib);
        XSANY.any_i32 = 0;
        newXS_deffile("DBD::SQLite::st::DESTROY", XS_DBD__SQLite__st_DESTROY);
#if XSubPPtmpAAAM
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_TXN_NONE", XS_DBD__SQLite__Constants__const_allowed_return_values_from_sqlite3_txn_state_3034000, file, "");
        XSANY.any_i32 = SQLITE_TXN_NONE;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_TXN_READ", XS_DBD__SQLite__Constants__const_allowed_return_values_from_sqlite3_txn_state_3034000, file, "");
        XSANY.any_i32 = SQLITE_TXN_READ;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_TXN_WRITE", XS_DBD__SQLite__Constants__const_allowed_return_values_from_sqlite3_txn_state_3034000, file, "");
        XSANY.any_i32 = SQLITE_TXN_WRITE;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_allowed_return_values_from_sqlite3_txn_state_3034000", XS_DBD__SQLite__Constants__const_allowed_return_values_from_sqlite3_txn_state_3034000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAAN
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_TXN_NONE", XS_DBD__SQLite__Constants__const_allowed_return_values_from_sqlite3_txn_state_3034000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_TXN_READ", XS_DBD__SQLite__Constants__const_allowed_return_values_from_sqlite3_txn_state_3034000_zero, file, "");
        XSANY.any_i32 = 2;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_TXN_WRITE", XS_DBD__SQLite__Constants__const_allowed_return_values_from_sqlite3_txn_state_3034000_zero, file, "");
        XSANY.any_i32 = 3;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_allowed_return_values_from_sqlite3_txn_state_3034000_zero", XS_DBD__SQLite__Constants__const_allowed_return_values_from_sqlite3_txn_state_3034000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_ALTER_TABLE", XS_DBD__SQLite__Constants__const_authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_ALTER_TABLE;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_ANALYZE", XS_DBD__SQLite__Constants__const_authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_ANALYZE;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_ATTACH", XS_DBD__SQLite__Constants__const_authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_ATTACH;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_COPY", XS_DBD__SQLite__Constants__const_authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_COPY;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CREATE_INDEX", XS_DBD__SQLite__Constants__const_authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_CREATE_INDEX;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CREATE_TABLE", XS_DBD__SQLite__Constants__const_authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_CREATE_TABLE;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CREATE_TEMP_INDEX", XS_DBD__SQLite__Constants__const_authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_CREATE_TEMP_INDEX;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CREATE_TEMP_TABLE", XS_DBD__SQLite__Constants__const_authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_CREATE_TEMP_TABLE;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CREATE_TEMP_TRIGGER", XS_DBD__SQLite__Constants__const_authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_CREATE_TEMP_TRIGGER;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CREATE_TEMP_VIEW", XS_DBD__SQLite__Constants__const_authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_CREATE_TEMP_VIEW;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CREATE_TRIGGER", XS_DBD__SQLite__Constants__const_authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_CREATE_TRIGGER;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CREATE_VIEW", XS_DBD__SQLite__Constants__const_authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_CREATE_VIEW;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CREATE_VTABLE", XS_DBD__SQLite__Constants__const_authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_CREATE_VTABLE;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DELETE", XS_DBD__SQLite__Constants__const_authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_DELETE;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DETACH", XS_DBD__SQLite__Constants__const_authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_DETACH;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DROP_INDEX", XS_DBD__SQLite__Constants__const_authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_DROP_INDEX;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DROP_TABLE", XS_DBD__SQLite__Constants__const_authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_DROP_TABLE;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DROP_TEMP_INDEX", XS_DBD__SQLite__Constants__const_authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_DROP_TEMP_INDEX;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DROP_TEMP_TABLE", XS_DBD__SQLite__Constants__const_authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_DROP_TEMP_TABLE;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DROP_TEMP_TRIGGER", XS_DBD__SQLite__Constants__const_authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_DROP_TEMP_TRIGGER;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DROP_TEMP_VIEW", XS_DBD__SQLite__Constants__const_authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_DROP_TEMP_VIEW;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DROP_TRIGGER", XS_DBD__SQLite__Constants__const_authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_DROP_TRIGGER;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DROP_VIEW", XS_DBD__SQLite__Constants__const_authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_DROP_VIEW;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DROP_VTABLE", XS_DBD__SQLite__Constants__const_authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_DROP_VTABLE;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_FUNCTION", XS_DBD__SQLite__Constants__const_authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_FUNCTION;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_INSERT", XS_DBD__SQLite__Constants__const_authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_INSERT;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_PRAGMA", XS_DBD__SQLite__Constants__const_authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_PRAGMA;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_READ", XS_DBD__SQLite__Constants__const_authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_READ;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_REINDEX", XS_DBD__SQLite__Constants__const_authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_REINDEX;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_SELECT", XS_DBD__SQLite__Constants__const_authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_SELECT;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_TRANSACTION", XS_DBD__SQLite__Constants__const_authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_TRANSACTION;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_UPDATE", XS_DBD__SQLite__Constants__const_authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_UPDATE;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_authorizer_action_codes", XS_DBD__SQLite__Constants__const_authorizer_action_codes, file, "");
        XSANY.any_i32 = 0;
#if XSubPPtmpAAAO
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_SAVEPOINT", XS_DBD__SQLite__Constants__const_authorizer_action_codes_3006008, file, "");
        XSANY.any_i32 = SQLITE_SAVEPOINT;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_authorizer_action_codes_3006008", XS_DBD__SQLite__Constants__const_authorizer_action_codes_3006008, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAAP
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_SAVEPOINT", XS_DBD__SQLite__Constants__const_authorizer_action_codes_3006008_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_authorizer_action_codes_3006008_zero", XS_DBD__SQLite__Constants__const_authorizer_action_codes_3006008_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAAQ
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_RECURSIVE", XS_DBD__SQLite__Constants__const_authorizer_action_codes_3008003, file, "");
        XSANY.any_i32 = SQLITE_RECURSIVE;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_authorizer_action_codes_3008003", XS_DBD__SQLite__Constants__const_authorizer_action_codes_3008003, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAAR
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_RECURSIVE", XS_DBD__SQLite__Constants__const_authorizer_action_codes_3008003_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_authorizer_action_codes_3008003_zero", XS_DBD__SQLite__Constants__const_authorizer_action_codes_3008003_zero, file, "");
        XSANY.any_i32 = 0;
#endif
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DENY", XS_DBD__SQLite__Constants__const_authorizer_return_codes, file, "");
        XSANY.any_i32 = SQLITE_DENY;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IGNORE", XS_DBD__SQLite__Constants__const_authorizer_return_codes, file, "");
        XSANY.any_i32 = SQLITE_IGNORE;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_authorizer_return_codes", XS_DBD__SQLite__Constants__const_authorizer_return_codes, file, "");
        XSANY.any_i32 = 0;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_VERSION_NUMBER", XS_DBD__SQLite__Constants__const_compile_time_library_version_numbers, file, "");
        XSANY.any_i32 = SQLITE_VERSION_NUMBER;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_compile_time_library_version_numbers", XS_DBD__SQLite__Constants__const_compile_time_library_version_numbers, file, "");
        XSANY.any_i32 = 0;
#if XSubPPtmpAAAS
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_LOOKASIDE", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3007000, file, "");
        XSANY.any_i32 = SQLITE_DBCONFIG_LOOKASIDE;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_database_connection_configuration_options_3007000", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3007000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAAT
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_LOOKASIDE", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3007000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_database_connection_configuration_options_3007000_zero", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3007000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAAU
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_ENABLE_FKEY", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3007006, file, "");
        XSANY.any_i32 = SQLITE_DBCONFIG_ENABLE_FKEY;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_ENABLE_TRIGGER", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3007006, file, "");
        XSANY.any_i32 = SQLITE_DBCONFIG_ENABLE_TRIGGER;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_database_connection_configuration_options_3007006", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3007006, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAAV
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_ENABLE_FKEY", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3007006_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_ENABLE_TRIGGER", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3007006_zero, file, "");
        XSANY.any_i32 = 2;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_database_connection_configuration_options_3007006_zero", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3007006_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAAW
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_ENABLE_FTS3_TOKENIZER", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3012002, file, "");
        XSANY.any_i32 = SQLITE_DBCONFIG_ENABLE_FTS3_TOKENIZER;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_database_connection_configuration_options_3012002", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3012002, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAAX
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_ENABLE_FTS3_TOKENIZER", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3012002_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_database_connection_configuration_options_3012002_zero", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3012002_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAAY
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_ENABLE_LOAD_EXTENSION", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3013000, file, "");
        XSANY.any_i32 = SQLITE_DBCONFIG_ENABLE_LOAD_EXTENSION;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_database_connection_configuration_options_3013000", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3013000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAAZ
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_ENABLE_LOAD_EXTENSION", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3013000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_database_connection_configuration_options_3013000_zero", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3013000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAABA
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_MAINDBNAME", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3015000, file, "");
        XSANY.any_i32 = SQLITE_DBCONFIG_MAINDBNAME;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_database_connection_configuration_options_3015000", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3015000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAABB
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_MAINDBNAME", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3015000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_database_connection_configuration_options_3015000_zero", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3015000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAABC
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_NO_CKPT_ON_CLOSE", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3016000, file, "");
        XSANY.any_i32 = SQLITE_DBCONFIG_NO_CKPT_ON_CLOSE;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_database_connection_configuration_options_3016000", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3016000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAABD
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_NO_CKPT_ON_CLOSE", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3016000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_database_connection_configuration_options_3016000_zero", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3016000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAABE
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_ENABLE_QPSG", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3020000, file, "");
        XSANY.any_i32 = SQLITE_DBCONFIG_ENABLE_QPSG;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_database_connection_configuration_options_3020000", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3020000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAABF
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_ENABLE_QPSG", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3020000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_database_connection_configuration_options_3020000_zero", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3020000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAABG
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_MAX", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3022000, file, "");
        XSANY.any_i32 = SQLITE_DBCONFIG_MAX;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_TRIGGER_EQP", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3022000, file, "");
        XSANY.any_i32 = SQLITE_DBCONFIG_TRIGGER_EQP;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_database_connection_configuration_options_3022000", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3022000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAABH
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_MAX", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3022000_zero, file, "");
        XSANY.any_i32 = 2;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_TRIGGER_EQP", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3022000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_database_connection_configuration_options_3022000_zero", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3022000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAABI
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_RESET_DATABASE", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3024000, file, "");
        XSANY.any_i32 = SQLITE_DBCONFIG_RESET_DATABASE;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_database_connection_configuration_options_3024000", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3024000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAABJ
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_RESET_DATABASE", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3024000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_database_connection_configuration_options_3024000_zero", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3024000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAABK
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_DEFENSIVE", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3026000, file, "");
        XSANY.any_i32 = SQLITE_DBCONFIG_DEFENSIVE;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_database_connection_configuration_options_3026000", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3026000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAABL
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_DEFENSIVE", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3026000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_database_connection_configuration_options_3026000_zero", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3026000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAABM
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_WRITABLE_SCHEMA", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3028000, file, "");
        XSANY.any_i32 = SQLITE_DBCONFIG_WRITABLE_SCHEMA;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_database_connection_configuration_options_3028000", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3028000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAABN
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_WRITABLE_SCHEMA", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3028000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_database_connection_configuration_options_3028000_zero", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3028000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAABO
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_DQS_DDL", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3029000, file, "");
        XSANY.any_i32 = SQLITE_DBCONFIG_DQS_DDL;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_DQS_DML", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3029000, file, "");
        XSANY.any_i32 = SQLITE_DBCONFIG_DQS_DML;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_LEGACY_ALTER_TABLE", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3029000, file, "");
        XSANY.any_i32 = SQLITE_DBCONFIG_LEGACY_ALTER_TABLE;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_database_connection_configuration_options_3029000", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3029000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAABP
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_DQS_DDL", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3029000_zero, file, "");
        XSANY.any_i32 = 3;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_DQS_DML", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3029000_zero, file, "");
        XSANY.any_i32 = 2;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_LEGACY_ALTER_TABLE", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3029000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_database_connection_configuration_options_3029000_zero", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3029000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAABQ
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_ENABLE_VIEW", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3030000, file, "");
        XSANY.any_i32 = SQLITE_DBCONFIG_ENABLE_VIEW;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_database_connection_configuration_options_3030000", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3030000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAABR
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_ENABLE_VIEW", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3030000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_database_connection_configuration_options_3030000_zero", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3030000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAABS
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_LEGACY_FILE_FORMAT", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3031000, file, "");
        XSANY.any_i32 = SQLITE_DBCONFIG_LEGACY_FILE_FORMAT;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_TRUSTED_SCHEMA", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3031000, file, "");
        XSANY.any_i32 = SQLITE_DBCONFIG_TRUSTED_SCHEMA;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_database_connection_configuration_options_3031000", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3031000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAABT
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_LEGACY_FILE_FORMAT", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3031000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_TRUSTED_SCHEMA", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3031000_zero, file, "");
        XSANY.any_i32 = 2;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_database_connection_configuration_options_3031000_zero", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3031000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAABU
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_REVERSE_SCANORDER", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3042000, file, "");
        XSANY.any_i32 = SQLITE_DBCONFIG_REVERSE_SCANORDER;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_STMT_SCANSTATUS", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3042000, file, "");
        XSANY.any_i32 = SQLITE_DBCONFIG_STMT_SCANSTATUS;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_database_connection_configuration_options_3042000", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3042000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAABV
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_REVERSE_SCANORDER", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3042000_zero, file, "");
        XSANY.any_i32 = 2;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_STMT_SCANSTATUS", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3042000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_database_connection_configuration_options_3042000_zero", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3042000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAABW
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_ENABLE_ATTACH_CREATE", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3049000, file, "");
        XSANY.any_i32 = SQLITE_DBCONFIG_ENABLE_ATTACH_CREATE;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_ENABLE_ATTACH_WRITE", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3049000, file, "");
        XSANY.any_i32 = SQLITE_DBCONFIG_ENABLE_ATTACH_WRITE;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_ENABLE_COMMENTS", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3049000, file, "");
        XSANY.any_i32 = SQLITE_DBCONFIG_ENABLE_COMMENTS;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_database_connection_configuration_options_3049000", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3049000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAABX
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_ENABLE_ATTACH_CREATE", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3049000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_ENABLE_ATTACH_WRITE", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3049000_zero, file, "");
        XSANY.any_i32 = 2;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DBCONFIG_ENABLE_COMMENTS", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3049000_zero, file, "");
        XSANY.any_i32 = 3;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_database_connection_configuration_options_3049000_zero", XS_DBD__SQLite__Constants__const_database_connection_configuration_options_3049000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAABY
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_LOCK", XS_DBD__SQLite__Constants__const_extended_result_codes_3006002, file, "");
        XSANY.any_i32 = SQLITE_IOERR_LOCK;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3006002", XS_DBD__SQLite__Constants__const_extended_result_codes_3006002, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAABZ
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_LOCK", XS_DBD__SQLite__Constants__const_extended_result_codes_3006002_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3006002_zero", XS_DBD__SQLite__Constants__const_extended_result_codes_3006002_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAACA
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_ACCESS", XS_DBD__SQLite__Constants__const_extended_result_codes_3006005, file, "");
        XSANY.any_i32 = SQLITE_IOERR_ACCESS;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_BLOCKED", XS_DBD__SQLite__Constants__const_extended_result_codes_3006005, file, "");
        XSANY.any_i32 = SQLITE_IOERR_BLOCKED;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_CHECKRESERVEDLOCK", XS_DBD__SQLite__Constants__const_extended_result_codes_3006005, file, "");
        XSANY.any_i32 = SQLITE_IOERR_CHECKRESERVEDLOCK;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_DELETE", XS_DBD__SQLite__Constants__const_extended_result_codes_3006005, file, "");
        XSANY.any_i32 = SQLITE_IOERR_DELETE;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_DIR_FSYNC", XS_DBD__SQLite__Constants__const_extended_result_codes_3006005, file, "");
        XSANY.any_i32 = SQLITE_IOERR_DIR_FSYNC;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_FSTAT", XS_DBD__SQLite__Constants__const_extended_result_codes_3006005, file, "");
        XSANY.any_i32 = SQLITE_IOERR_FSTAT;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_FSYNC", XS_DBD__SQLite__Constants__const_extended_result_codes_3006005, file, "");
        XSANY.any_i32 = SQLITE_IOERR_FSYNC;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_NOMEM", XS_DBD__SQLite__Constants__const_extended_result_codes_3006005, file, "");
        XSANY.any_i32 = SQLITE_IOERR_NOMEM;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_RDLOCK", XS_DBD__SQLite__Constants__const_extended_result_codes_3006005, file, "");
        XSANY.any_i32 = SQLITE_IOERR_RDLOCK;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_READ", XS_DBD__SQLite__Constants__const_extended_result_codes_3006005, file, "");
        XSANY.any_i32 = SQLITE_IOERR_READ;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_SHORT_READ", XS_DBD__SQLite__Constants__const_extended_result_codes_3006005, file, "");
        XSANY.any_i32 = SQLITE_IOERR_SHORT_READ;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_TRUNCATE", XS_DBD__SQLite__Constants__const_extended_result_codes_3006005, file, "");
        XSANY.any_i32 = SQLITE_IOERR_TRUNCATE;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_UNLOCK", XS_DBD__SQLite__Constants__const_extended_result_codes_3006005, file, "");
        XSANY.any_i32 = SQLITE_IOERR_UNLOCK;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_WRITE", XS_DBD__SQLite__Constants__const_extended_result_codes_3006005, file, "");
        XSANY.any_i32 = SQLITE_IOERR_WRITE;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3006005", XS_DBD__SQLite__Constants__const_extended_result_codes_3006005, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAACB
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_ACCESS", XS_DBD__SQLite__Constants__const_extended_result_codes_3006005_zero, file, "");
        XSANY.any_i32 = 13;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_BLOCKED", XS_DBD__SQLite__Constants__const_extended_result_codes_3006005_zero, file, "");
        XSANY.any_i32 = 11;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_CHECKRESERVEDLOCK", XS_DBD__SQLite__Constants__const_extended_result_codes_3006005_zero, file, "");
        XSANY.any_i32 = 14;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_DELETE", XS_DBD__SQLite__Constants__const_extended_result_codes_3006005_zero, file, "");
        XSANY.any_i32 = 10;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_DIR_FSYNC", XS_DBD__SQLite__Constants__const_extended_result_codes_3006005_zero, file, "");
        XSANY.any_i32 = 5;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_FSTAT", XS_DBD__SQLite__Constants__const_extended_result_codes_3006005_zero, file, "");
        XSANY.any_i32 = 7;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_FSYNC", XS_DBD__SQLite__Constants__const_extended_result_codes_3006005_zero, file, "");
        XSANY.any_i32 = 4;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_NOMEM", XS_DBD__SQLite__Constants__const_extended_result_codes_3006005_zero, file, "");
        XSANY.any_i32 = 12;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_RDLOCK", XS_DBD__SQLite__Constants__const_extended_result_codes_3006005_zero, file, "");
        XSANY.any_i32 = 9;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_READ", XS_DBD__SQLite__Constants__const_extended_result_codes_3006005_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_SHORT_READ", XS_DBD__SQLite__Constants__const_extended_result_codes_3006005_zero, file, "");
        XSANY.any_i32 = 2;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_TRUNCATE", XS_DBD__SQLite__Constants__const_extended_result_codes_3006005_zero, file, "");
        XSANY.any_i32 = 6;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_UNLOCK", XS_DBD__SQLite__Constants__const_extended_result_codes_3006005_zero, file, "");
        XSANY.any_i32 = 8;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_WRITE", XS_DBD__SQLite__Constants__const_extended_result_codes_3006005_zero, file, "");
        XSANY.any_i32 = 3;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3006005_zero", XS_DBD__SQLite__Constants__const_extended_result_codes_3006005_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAACC
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_CLOSE", XS_DBD__SQLite__Constants__const_extended_result_codes_3006007, file, "");
        XSANY.any_i32 = SQLITE_IOERR_CLOSE;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_DIR_CLOSE", XS_DBD__SQLite__Constants__const_extended_result_codes_3006007, file, "");
        XSANY.any_i32 = SQLITE_IOERR_DIR_CLOSE;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3006007", XS_DBD__SQLite__Constants__const_extended_result_codes_3006007, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAACD
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_CLOSE", XS_DBD__SQLite__Constants__const_extended_result_codes_3006007_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_DIR_CLOSE", XS_DBD__SQLite__Constants__const_extended_result_codes_3006007_zero, file, "");
        XSANY.any_i32 = 2;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3006007_zero", XS_DBD__SQLite__Constants__const_extended_result_codes_3006007_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAACE
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_LOCKED_SHAREDCACHE", XS_DBD__SQLite__Constants__const_extended_result_codes_3006012, file, "");
        XSANY.any_i32 = SQLITE_LOCKED_SHAREDCACHE;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3006012", XS_DBD__SQLite__Constants__const_extended_result_codes_3006012, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAACF
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_LOCKED_SHAREDCACHE", XS_DBD__SQLite__Constants__const_extended_result_codes_3006012_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3006012_zero", XS_DBD__SQLite__Constants__const_extended_result_codes_3006012_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAACG
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_BUSY_RECOVERY", XS_DBD__SQLite__Constants__const_extended_result_codes_3007000, file, "");
        XSANY.any_i32 = SQLITE_BUSY_RECOVERY;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CANTOPEN_NOTEMPDIR", XS_DBD__SQLite__Constants__const_extended_result_codes_3007000, file, "");
        XSANY.any_i32 = SQLITE_CANTOPEN_NOTEMPDIR;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_SHMLOCK", XS_DBD__SQLite__Constants__const_extended_result_codes_3007000, file, "");
        XSANY.any_i32 = SQLITE_IOERR_SHMLOCK;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_SHMOPEN", XS_DBD__SQLite__Constants__const_extended_result_codes_3007000, file, "");
        XSANY.any_i32 = SQLITE_IOERR_SHMOPEN;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_SHMSIZE", XS_DBD__SQLite__Constants__const_extended_result_codes_3007000, file, "");
        XSANY.any_i32 = SQLITE_IOERR_SHMSIZE;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3007000", XS_DBD__SQLite__Constants__const_extended_result_codes_3007000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAACH
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_BUSY_RECOVERY", XS_DBD__SQLite__Constants__const_extended_result_codes_3007000_zero, file, "");
        XSANY.any_i32 = 4;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CANTOPEN_NOTEMPDIR", XS_DBD__SQLite__Constants__const_extended_result_codes_3007000_zero, file, "");
        XSANY.any_i32 = 5;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_SHMLOCK", XS_DBD__SQLite__Constants__const_extended_result_codes_3007000_zero, file, "");
        XSANY.any_i32 = 3;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_SHMOPEN", XS_DBD__SQLite__Constants__const_extended_result_codes_3007000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_SHMSIZE", XS_DBD__SQLite__Constants__const_extended_result_codes_3007000_zero, file, "");
        XSANY.any_i32 = 2;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3007000_zero", XS_DBD__SQLite__Constants__const_extended_result_codes_3007000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAACI
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CORRUPT_VTAB", XS_DBD__SQLite__Constants__const_extended_result_codes_3007007, file, "");
        XSANY.any_i32 = SQLITE_CORRUPT_VTAB;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_SEEK", XS_DBD__SQLite__Constants__const_extended_result_codes_3007007, file, "");
        XSANY.any_i32 = SQLITE_IOERR_SEEK;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_SHMMAP", XS_DBD__SQLite__Constants__const_extended_result_codes_3007007, file, "");
        XSANY.any_i32 = SQLITE_IOERR_SHMMAP;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_READONLY_CANTLOCK", XS_DBD__SQLite__Constants__const_extended_result_codes_3007007, file, "");
        XSANY.any_i32 = SQLITE_READONLY_CANTLOCK;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_READONLY_RECOVERY", XS_DBD__SQLite__Constants__const_extended_result_codes_3007007, file, "");
        XSANY.any_i32 = SQLITE_READONLY_RECOVERY;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3007007", XS_DBD__SQLite__Constants__const_extended_result_codes_3007007, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAACJ
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CORRUPT_VTAB", XS_DBD__SQLite__Constants__const_extended_result_codes_3007007_zero, file, "");
        XSANY.any_i32 = 3;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_SEEK", XS_DBD__SQLite__Constants__const_extended_result_codes_3007007_zero, file, "");
        XSANY.any_i32 = 2;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_SHMMAP", XS_DBD__SQLite__Constants__const_extended_result_codes_3007007_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_READONLY_CANTLOCK", XS_DBD__SQLite__Constants__const_extended_result_codes_3007007_zero, file, "");
        XSANY.any_i32 = 5;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_READONLY_RECOVERY", XS_DBD__SQLite__Constants__const_extended_result_codes_3007007_zero, file, "");
        XSANY.any_i32 = 4;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3007007_zero", XS_DBD__SQLite__Constants__const_extended_result_codes_3007007_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAACK
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_ABORT_ROLLBACK", XS_DBD__SQLite__Constants__const_extended_result_codes_3007011, file, "");
        XSANY.any_i32 = SQLITE_ABORT_ROLLBACK;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3007011", XS_DBD__SQLite__Constants__const_extended_result_codes_3007011, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAACL
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_ABORT_ROLLBACK", XS_DBD__SQLite__Constants__const_extended_result_codes_3007011_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3007011_zero", XS_DBD__SQLite__Constants__const_extended_result_codes_3007011_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAACM
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CANTOPEN_ISDIR", XS_DBD__SQLite__Constants__const_extended_result_codes_3007012, file, "");
        XSANY.any_i32 = SQLITE_CANTOPEN_ISDIR;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3007012", XS_DBD__SQLite__Constants__const_extended_result_codes_3007012, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAACN
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CANTOPEN_ISDIR", XS_DBD__SQLite__Constants__const_extended_result_codes_3007012_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3007012_zero", XS_DBD__SQLite__Constants__const_extended_result_codes_3007012_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAACO
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CANTOPEN_FULLPATH", XS_DBD__SQLite__Constants__const_extended_result_codes_3007015, file, "");
        XSANY.any_i32 = SQLITE_CANTOPEN_FULLPATH;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_DELETE_NOENT", XS_DBD__SQLite__Constants__const_extended_result_codes_3007015, file, "");
        XSANY.any_i32 = SQLITE_IOERR_DELETE_NOENT;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3007015", XS_DBD__SQLite__Constants__const_extended_result_codes_3007015, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAACP
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CANTOPEN_FULLPATH", XS_DBD__SQLite__Constants__const_extended_result_codes_3007015_zero, file, "");
        XSANY.any_i32 = 2;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_DELETE_NOENT", XS_DBD__SQLite__Constants__const_extended_result_codes_3007015_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3007015_zero", XS_DBD__SQLite__Constants__const_extended_result_codes_3007015_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAACQ
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CONSTRAINT_CHECK", XS_DBD__SQLite__Constants__const_extended_result_codes_3007016, file, "");
        XSANY.any_i32 = SQLITE_CONSTRAINT_CHECK;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CONSTRAINT_COMMITHOOK", XS_DBD__SQLite__Constants__const_extended_result_codes_3007016, file, "");
        XSANY.any_i32 = SQLITE_CONSTRAINT_COMMITHOOK;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CONSTRAINT_FOREIGNKEY", XS_DBD__SQLite__Constants__const_extended_result_codes_3007016, file, "");
        XSANY.any_i32 = SQLITE_CONSTRAINT_FOREIGNKEY;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CONSTRAINT_FUNCTION", XS_DBD__SQLite__Constants__const_extended_result_codes_3007016, file, "");
        XSANY.any_i32 = SQLITE_CONSTRAINT_FUNCTION;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CONSTRAINT_NOTNULL", XS_DBD__SQLite__Constants__const_extended_result_codes_3007016, file, "");
        XSANY.any_i32 = SQLITE_CONSTRAINT_NOTNULL;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CONSTRAINT_PRIMARYKEY", XS_DBD__SQLite__Constants__const_extended_result_codes_3007016, file, "");
        XSANY.any_i32 = SQLITE_CONSTRAINT_PRIMARYKEY;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CONSTRAINT_TRIGGER", XS_DBD__SQLite__Constants__const_extended_result_codes_3007016, file, "");
        XSANY.any_i32 = SQLITE_CONSTRAINT_TRIGGER;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CONSTRAINT_UNIQUE", XS_DBD__SQLite__Constants__const_extended_result_codes_3007016, file, "");
        XSANY.any_i32 = SQLITE_CONSTRAINT_UNIQUE;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CONSTRAINT_VTAB", XS_DBD__SQLite__Constants__const_extended_result_codes_3007016, file, "");
        XSANY.any_i32 = SQLITE_CONSTRAINT_VTAB;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_READONLY_ROLLBACK", XS_DBD__SQLite__Constants__const_extended_result_codes_3007016, file, "");
        XSANY.any_i32 = SQLITE_READONLY_ROLLBACK;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3007016", XS_DBD__SQLite__Constants__const_extended_result_codes_3007016, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAACR
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CONSTRAINT_CHECK", XS_DBD__SQLite__Constants__const_extended_result_codes_3007016_zero, file, "");
        XSANY.any_i32 = 2;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CONSTRAINT_COMMITHOOK", XS_DBD__SQLite__Constants__const_extended_result_codes_3007016_zero, file, "");
        XSANY.any_i32 = 3;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CONSTRAINT_FOREIGNKEY", XS_DBD__SQLite__Constants__const_extended_result_codes_3007016_zero, file, "");
        XSANY.any_i32 = 4;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CONSTRAINT_FUNCTION", XS_DBD__SQLite__Constants__const_extended_result_codes_3007016_zero, file, "");
        XSANY.any_i32 = 5;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CONSTRAINT_NOTNULL", XS_DBD__SQLite__Constants__const_extended_result_codes_3007016_zero, file, "");
        XSANY.any_i32 = 6;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CONSTRAINT_PRIMARYKEY", XS_DBD__SQLite__Constants__const_extended_result_codes_3007016_zero, file, "");
        XSANY.any_i32 = 7;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CONSTRAINT_TRIGGER", XS_DBD__SQLite__Constants__const_extended_result_codes_3007016_zero, file, "");
        XSANY.any_i32 = 8;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CONSTRAINT_UNIQUE", XS_DBD__SQLite__Constants__const_extended_result_codes_3007016_zero, file, "");
        XSANY.any_i32 = 9;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CONSTRAINT_VTAB", XS_DBD__SQLite__Constants__const_extended_result_codes_3007016_zero, file, "");
        XSANY.any_i32 = 10;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_READONLY_ROLLBACK", XS_DBD__SQLite__Constants__const_extended_result_codes_3007016_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3007016_zero", XS_DBD__SQLite__Constants__const_extended_result_codes_3007016_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAACS
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_MMAP", XS_DBD__SQLite__Constants__const_extended_result_codes_3007017, file, "");
        XSANY.any_i32 = SQLITE_IOERR_MMAP;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_NOTICE_RECOVER_ROLLBACK", XS_DBD__SQLite__Constants__const_extended_result_codes_3007017, file, "");
        XSANY.any_i32 = SQLITE_NOTICE_RECOVER_ROLLBACK;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_NOTICE_RECOVER_WAL", XS_DBD__SQLite__Constants__const_extended_result_codes_3007017, file, "");
        XSANY.any_i32 = SQLITE_NOTICE_RECOVER_WAL;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3007017", XS_DBD__SQLite__Constants__const_extended_result_codes_3007017, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAACT
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_MMAP", XS_DBD__SQLite__Constants__const_extended_result_codes_3007017_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_NOTICE_RECOVER_ROLLBACK", XS_DBD__SQLite__Constants__const_extended_result_codes_3007017_zero, file, "");
        XSANY.any_i32 = 3;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_NOTICE_RECOVER_WAL", XS_DBD__SQLite__Constants__const_extended_result_codes_3007017_zero, file, "");
        XSANY.any_i32 = 2;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3007017_zero", XS_DBD__SQLite__Constants__const_extended_result_codes_3007017_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAACU
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_BUSY_SNAPSHOT", XS_DBD__SQLite__Constants__const_extended_result_codes_3008000, file, "");
        XSANY.any_i32 = SQLITE_BUSY_SNAPSHOT;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_GETTEMPPATH", XS_DBD__SQLite__Constants__const_extended_result_codes_3008000, file, "");
        XSANY.any_i32 = SQLITE_IOERR_GETTEMPPATH;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_WARNING_AUTOINDEX", XS_DBD__SQLite__Constants__const_extended_result_codes_3008000, file, "");
        XSANY.any_i32 = SQLITE_WARNING_AUTOINDEX;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3008000", XS_DBD__SQLite__Constants__const_extended_result_codes_3008000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAACV
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_BUSY_SNAPSHOT", XS_DBD__SQLite__Constants__const_extended_result_codes_3008000_zero, file, "");
        XSANY.any_i32 = 2;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_GETTEMPPATH", XS_DBD__SQLite__Constants__const_extended_result_codes_3008000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_WARNING_AUTOINDEX", XS_DBD__SQLite__Constants__const_extended_result_codes_3008000_zero, file, "");
        XSANY.any_i32 = 3;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3008000_zero", XS_DBD__SQLite__Constants__const_extended_result_codes_3008000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAACW
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CANTOPEN_CONVPATH", XS_DBD__SQLite__Constants__const_extended_result_codes_3008001, file, "");
        XSANY.any_i32 = SQLITE_CANTOPEN_CONVPATH;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_CONVPATH", XS_DBD__SQLite__Constants__const_extended_result_codes_3008001, file, "");
        XSANY.any_i32 = SQLITE_IOERR_CONVPATH;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3008001", XS_DBD__SQLite__Constants__const_extended_result_codes_3008001, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAACX
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CANTOPEN_CONVPATH", XS_DBD__SQLite__Constants__const_extended_result_codes_3008001_zero, file, "");
        XSANY.any_i32 = 2;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_CONVPATH", XS_DBD__SQLite__Constants__const_extended_result_codes_3008001_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3008001_zero", XS_DBD__SQLite__Constants__const_extended_result_codes_3008001_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAACY
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CONSTRAINT_ROWID", XS_DBD__SQLite__Constants__const_extended_result_codes_3008002, file, "");
        XSANY.any_i32 = SQLITE_CONSTRAINT_ROWID;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3008002", XS_DBD__SQLite__Constants__const_extended_result_codes_3008002, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAACZ
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CONSTRAINT_ROWID", XS_DBD__SQLite__Constants__const_extended_result_codes_3008002_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3008002_zero", XS_DBD__SQLite__Constants__const_extended_result_codes_3008002_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAADA
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_READONLY_DBMOVED", XS_DBD__SQLite__Constants__const_extended_result_codes_3008003, file, "");
        XSANY.any_i32 = SQLITE_READONLY_DBMOVED;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3008003", XS_DBD__SQLite__Constants__const_extended_result_codes_3008003, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAADB
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_READONLY_DBMOVED", XS_DBD__SQLite__Constants__const_extended_result_codes_3008003_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3008003_zero", XS_DBD__SQLite__Constants__const_extended_result_codes_3008003_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAADC
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_AUTH_USER", XS_DBD__SQLite__Constants__const_extended_result_codes_3008007, file, "");
        XSANY.any_i32 = SQLITE_AUTH_USER;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3008007", XS_DBD__SQLite__Constants__const_extended_result_codes_3008007, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAADD
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_AUTH_USER", XS_DBD__SQLite__Constants__const_extended_result_codes_3008007_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3008007_zero", XS_DBD__SQLite__Constants__const_extended_result_codes_3008007_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAADE
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_VNODE", XS_DBD__SQLite__Constants__const_extended_result_codes_3009000, file, "");
        XSANY.any_i32 = SQLITE_IOERR_VNODE;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3009000", XS_DBD__SQLite__Constants__const_extended_result_codes_3009000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAADF
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_VNODE", XS_DBD__SQLite__Constants__const_extended_result_codes_3009000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3009000_zero", XS_DBD__SQLite__Constants__const_extended_result_codes_3009000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAADG
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_AUTH", XS_DBD__SQLite__Constants__const_extended_result_codes_3010000, file, "");
        XSANY.any_i32 = SQLITE_IOERR_AUTH;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3010000", XS_DBD__SQLite__Constants__const_extended_result_codes_3010000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAADH
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_AUTH", XS_DBD__SQLite__Constants__const_extended_result_codes_3010000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3010000_zero", XS_DBD__SQLite__Constants__const_extended_result_codes_3010000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAADI
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_BEGIN_ATOMIC", XS_DBD__SQLite__Constants__const_extended_result_codes_3021000, file, "");
        XSANY.any_i32 = SQLITE_IOERR_BEGIN_ATOMIC;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_COMMIT_ATOMIC", XS_DBD__SQLite__Constants__const_extended_result_codes_3021000, file, "");
        XSANY.any_i32 = SQLITE_IOERR_COMMIT_ATOMIC;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_ROLLBACK_ATOMIC", XS_DBD__SQLite__Constants__const_extended_result_codes_3021000, file, "");
        XSANY.any_i32 = SQLITE_IOERR_ROLLBACK_ATOMIC;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3021000", XS_DBD__SQLite__Constants__const_extended_result_codes_3021000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAADJ
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_BEGIN_ATOMIC", XS_DBD__SQLite__Constants__const_extended_result_codes_3021000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_COMMIT_ATOMIC", XS_DBD__SQLite__Constants__const_extended_result_codes_3021000_zero, file, "");
        XSANY.any_i32 = 2;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_ROLLBACK_ATOMIC", XS_DBD__SQLite__Constants__const_extended_result_codes_3021000_zero, file, "");
        XSANY.any_i32 = 3;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3021000_zero", XS_DBD__SQLite__Constants__const_extended_result_codes_3021000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAADK
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_ERROR_MISSING_COLLSEQ", XS_DBD__SQLite__Constants__const_extended_result_codes_3022000, file, "");
        XSANY.any_i32 = SQLITE_ERROR_MISSING_COLLSEQ;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_ERROR_RETRY", XS_DBD__SQLite__Constants__const_extended_result_codes_3022000, file, "");
        XSANY.any_i32 = SQLITE_ERROR_RETRY;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_READONLY_CANTINIT", XS_DBD__SQLite__Constants__const_extended_result_codes_3022000, file, "");
        XSANY.any_i32 = SQLITE_READONLY_CANTINIT;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_READONLY_DIRECTORY", XS_DBD__SQLite__Constants__const_extended_result_codes_3022000, file, "");
        XSANY.any_i32 = SQLITE_READONLY_DIRECTORY;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3022000", XS_DBD__SQLite__Constants__const_extended_result_codes_3022000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAADL
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_ERROR_MISSING_COLLSEQ", XS_DBD__SQLite__Constants__const_extended_result_codes_3022000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_ERROR_RETRY", XS_DBD__SQLite__Constants__const_extended_result_codes_3022000_zero, file, "");
        XSANY.any_i32 = 2;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_READONLY_CANTINIT", XS_DBD__SQLite__Constants__const_extended_result_codes_3022000_zero, file, "");
        XSANY.any_i32 = 3;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_READONLY_DIRECTORY", XS_DBD__SQLite__Constants__const_extended_result_codes_3022000_zero, file, "");
        XSANY.any_i32 = 4;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3022000_zero", XS_DBD__SQLite__Constants__const_extended_result_codes_3022000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAADM
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CORRUPT_SEQUENCE", XS_DBD__SQLite__Constants__const_extended_result_codes_3024000, file, "");
        XSANY.any_i32 = SQLITE_CORRUPT_SEQUENCE;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_LOCKED_VTAB", XS_DBD__SQLite__Constants__const_extended_result_codes_3024000, file, "");
        XSANY.any_i32 = SQLITE_LOCKED_VTAB;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3024000", XS_DBD__SQLite__Constants__const_extended_result_codes_3024000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAADN
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CORRUPT_SEQUENCE", XS_DBD__SQLite__Constants__const_extended_result_codes_3024000_zero, file, "");
        XSANY.any_i32 = 2;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_LOCKED_VTAB", XS_DBD__SQLite__Constants__const_extended_result_codes_3024000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3024000_zero", XS_DBD__SQLite__Constants__const_extended_result_codes_3024000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAADO
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CANTOPEN_DIRTYWAL", XS_DBD__SQLite__Constants__const_extended_result_codes_3025000, file, "");
        XSANY.any_i32 = SQLITE_CANTOPEN_DIRTYWAL;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_ERROR_SNAPSHOT", XS_DBD__SQLite__Constants__const_extended_result_codes_3025000, file, "");
        XSANY.any_i32 = SQLITE_ERROR_SNAPSHOT;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3025000", XS_DBD__SQLite__Constants__const_extended_result_codes_3025000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAADP
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CANTOPEN_DIRTYWAL", XS_DBD__SQLite__Constants__const_extended_result_codes_3025000_zero, file, "");
        XSANY.any_i32 = 2;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_ERROR_SNAPSHOT", XS_DBD__SQLite__Constants__const_extended_result_codes_3025000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3025000_zero", XS_DBD__SQLite__Constants__const_extended_result_codes_3025000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAADQ
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CANTOPEN_SYMLINK", XS_DBD__SQLite__Constants__const_extended_result_codes_3031000, file, "");
        XSANY.any_i32 = SQLITE_CANTOPEN_SYMLINK;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CONSTRAINT_PINNED", XS_DBD__SQLite__Constants__const_extended_result_codes_3031000, file, "");
        XSANY.any_i32 = SQLITE_CONSTRAINT_PINNED;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_OK_SYMLINK", XS_DBD__SQLite__Constants__const_extended_result_codes_3031000, file, "");
        XSANY.any_i32 = SQLITE_OK_SYMLINK;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3031000", XS_DBD__SQLite__Constants__const_extended_result_codes_3031000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAADR
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CANTOPEN_SYMLINK", XS_DBD__SQLite__Constants__const_extended_result_codes_3031000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CONSTRAINT_PINNED", XS_DBD__SQLite__Constants__const_extended_result_codes_3031000_zero, file, "");
        XSANY.any_i32 = 2;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_OK_SYMLINK", XS_DBD__SQLite__Constants__const_extended_result_codes_3031000_zero, file, "");
        XSANY.any_i32 = 3;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3031000_zero", XS_DBD__SQLite__Constants__const_extended_result_codes_3031000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAADS
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_BUSY_TIMEOUT", XS_DBD__SQLite__Constants__const_extended_result_codes_3032000, file, "");
        XSANY.any_i32 = SQLITE_BUSY_TIMEOUT;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CORRUPT_INDEX", XS_DBD__SQLite__Constants__const_extended_result_codes_3032000, file, "");
        XSANY.any_i32 = SQLITE_CORRUPT_INDEX;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_DATA", XS_DBD__SQLite__Constants__const_extended_result_codes_3032000, file, "");
        XSANY.any_i32 = SQLITE_IOERR_DATA;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3032000", XS_DBD__SQLite__Constants__const_extended_result_codes_3032000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAADT
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_BUSY_TIMEOUT", XS_DBD__SQLite__Constants__const_extended_result_codes_3032000_zero, file, "");
        XSANY.any_i32 = 2;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CORRUPT_INDEX", XS_DBD__SQLite__Constants__const_extended_result_codes_3032000_zero, file, "");
        XSANY.any_i32 = 3;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_DATA", XS_DBD__SQLite__Constants__const_extended_result_codes_3032000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3032000_zero", XS_DBD__SQLite__Constants__const_extended_result_codes_3032000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAADU
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_CORRUPTFS", XS_DBD__SQLite__Constants__const_extended_result_codes_3034000, file, "");
        XSANY.any_i32 = SQLITE_IOERR_CORRUPTFS;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3034000", XS_DBD__SQLite__Constants__const_extended_result_codes_3034000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAADV
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_CORRUPTFS", XS_DBD__SQLite__Constants__const_extended_result_codes_3034000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3034000_zero", XS_DBD__SQLite__Constants__const_extended_result_codes_3034000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAADW
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CONSTRAINT_DATATYPE", XS_DBD__SQLite__Constants__const_extended_result_codes_3037000, file, "");
        XSANY.any_i32 = SQLITE_CONSTRAINT_DATATYPE;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3037000", XS_DBD__SQLite__Constants__const_extended_result_codes_3037000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAADX
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CONSTRAINT_DATATYPE", XS_DBD__SQLite__Constants__const_extended_result_codes_3037000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3037000_zero", XS_DBD__SQLite__Constants__const_extended_result_codes_3037000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAADY
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_NOTICE_RBU", XS_DBD__SQLite__Constants__const_extended_result_codes_3041000, file, "");
        XSANY.any_i32 = SQLITE_NOTICE_RBU;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3041000", XS_DBD__SQLite__Constants__const_extended_result_codes_3041000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAADZ
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_NOTICE_RBU", XS_DBD__SQLite__Constants__const_extended_result_codes_3041000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3041000_zero", XS_DBD__SQLite__Constants__const_extended_result_codes_3041000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAEA
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_IN_PAGE", XS_DBD__SQLite__Constants__const_extended_result_codes_3043000, file, "");
        XSANY.any_i32 = SQLITE_IOERR_IN_PAGE;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3043000", XS_DBD__SQLite__Constants__const_extended_result_codes_3043000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAEB
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_IN_PAGE", XS_DBD__SQLite__Constants__const_extended_result_codes_3043000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3043000_zero", XS_DBD__SQLite__Constants__const_extended_result_codes_3043000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAEC
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_ERROR_KEY", XS_DBD__SQLite__Constants__const_extended_result_codes_3051000, file, "");
        XSANY.any_i32 = SQLITE_ERROR_KEY;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_ERROR_RESERVESIZE", XS_DBD__SQLite__Constants__const_extended_result_codes_3051000, file, "");
        XSANY.any_i32 = SQLITE_ERROR_RESERVESIZE;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_ERROR_UNABLE", XS_DBD__SQLite__Constants__const_extended_result_codes_3051000, file, "");
        XSANY.any_i32 = SQLITE_ERROR_UNABLE;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_BADKEY", XS_DBD__SQLite__Constants__const_extended_result_codes_3051000, file, "");
        XSANY.any_i32 = SQLITE_IOERR_BADKEY;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_CODEC", XS_DBD__SQLite__Constants__const_extended_result_codes_3051000, file, "");
        XSANY.any_i32 = SQLITE_IOERR_CODEC;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3051000", XS_DBD__SQLite__Constants__const_extended_result_codes_3051000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAED
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_ERROR_KEY", XS_DBD__SQLite__Constants__const_extended_result_codes_3051000_zero, file, "");
        XSANY.any_i32 = 2;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_ERROR_RESERVESIZE", XS_DBD__SQLite__Constants__const_extended_result_codes_3051000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_ERROR_UNABLE", XS_DBD__SQLite__Constants__const_extended_result_codes_3051000_zero, file, "");
        XSANY.any_i32 = 3;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_BADKEY", XS_DBD__SQLite__Constants__const_extended_result_codes_3051000_zero, file, "");
        XSANY.any_i32 = 4;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR_CODEC", XS_DBD__SQLite__Constants__const_extended_result_codes_3051000_zero, file, "");
        XSANY.any_i32 = 5;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_extended_result_codes_3051000_zero", XS_DBD__SQLite__Constants__const_extended_result_codes_3051000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_OPEN_CREATE", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations, file, "");
        XSANY.any_i32 = SQLITE_OPEN_CREATE;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_OPEN_NOMUTEX", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations, file, "");
        XSANY.any_i32 = SQLITE_OPEN_NOMUTEX;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_OPEN_READONLY", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations, file, "");
        XSANY.any_i32 = SQLITE_OPEN_READONLY;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_OPEN_READWRITE", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations, file, "");
        XSANY.any_i32 = SQLITE_OPEN_READWRITE;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_flags_for_file_open_operations", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations, file, "");
        XSANY.any_i32 = 0;
#if XSubPPtmpAAEE
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_OPEN_FULLMUTEX", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3006002, file, "");
        XSANY.any_i32 = SQLITE_OPEN_FULLMUTEX;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_flags_for_file_open_operations_3006002", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3006002, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAEF
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_OPEN_FULLMUTEX", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3006002_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_flags_for_file_open_operations_3006002_zero", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3006002_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAEG
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_OPEN_PRIVATECACHE", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3006018, file, "");
        XSANY.any_i32 = SQLITE_OPEN_PRIVATECACHE;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_OPEN_SHAREDCACHE", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3006018, file, "");
        XSANY.any_i32 = SQLITE_OPEN_SHAREDCACHE;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_flags_for_file_open_operations_3006018", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3006018, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAEH
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_OPEN_PRIVATECACHE", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3006018_zero, file, "");
        XSANY.any_i32 = 2;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_OPEN_SHAREDCACHE", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3006018_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_flags_for_file_open_operations_3006018_zero", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3006018_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAEI
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_OPEN_URI", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3007007, file, "");
        XSANY.any_i32 = SQLITE_OPEN_URI;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_flags_for_file_open_operations_3007007", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3007007, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAEJ
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_OPEN_URI", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3007007_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_flags_for_file_open_operations_3007007_zero", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3007007_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAEK
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_OPEN_MEMORY", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3007013, file, "");
        XSANY.any_i32 = SQLITE_OPEN_MEMORY;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_flags_for_file_open_operations_3007013", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3007013, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAEL
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_OPEN_MEMORY", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3007013_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_flags_for_file_open_operations_3007013_zero", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3007013_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAEM
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_OPEN_NOFOLLOW", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3031000, file, "");
        XSANY.any_i32 = SQLITE_OPEN_NOFOLLOW;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_flags_for_file_open_operations_3031000", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3031000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAEN
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_OPEN_NOFOLLOW", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3031000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_flags_for_file_open_operations_3031000_zero", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3031000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAEO
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_OPEN_SUPER_JOURNAL", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3033000, file, "");
        XSANY.any_i32 = SQLITE_OPEN_SUPER_JOURNAL;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_flags_for_file_open_operations_3033000", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3033000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAEP
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_OPEN_SUPER_JOURNAL", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3033000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_flags_for_file_open_operations_3033000_zero", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3033000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAEQ
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_OPEN_EXRESCODE", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3037000, file, "");
        XSANY.any_i32 = SQLITE_OPEN_EXRESCODE;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_flags_for_file_open_operations_3037000", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3037000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAER
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_OPEN_EXRESCODE", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3037000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_flags_for_file_open_operations_3037000_zero", XS_DBD__SQLite__Constants__const_flags_for_file_open_operations_3037000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAES
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_SETLK_BLOCK_ON_CONNECT", XS_DBD__SQLite__Constants__const_flags_for_sqlite3_setlk_timeout_3050000, file, "");
        XSANY.any_i32 = SQLITE_SETLK_BLOCK_ON_CONNECT;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_flags_for_sqlite3_setlk_timeout_3050000", XS_DBD__SQLite__Constants__const_flags_for_sqlite3_setlk_timeout_3050000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAET
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_SETLK_BLOCK_ON_CONNECT", XS_DBD__SQLite__Constants__const_flags_for_sqlite3_setlk_timeout_3050000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_flags_for_sqlite3_setlk_timeout_3050000_zero", XS_DBD__SQLite__Constants__const_flags_for_sqlite3_setlk_timeout_3050000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAEU
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DETERMINISTIC", XS_DBD__SQLite__Constants__const_function_flags_3008003, file, "");
        XSANY.any_i32 = SQLITE_DETERMINISTIC;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_function_flags_3008003", XS_DBD__SQLite__Constants__const_function_flags_3008003, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAEV
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DETERMINISTIC", XS_DBD__SQLite__Constants__const_function_flags_3008003_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_function_flags_3008003_zero", XS_DBD__SQLite__Constants__const_function_flags_3008003_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAEW
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DIRECTONLY", XS_DBD__SQLite__Constants__const_function_flags_3030000, file, "");
        XSANY.any_i32 = SQLITE_DIRECTONLY;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_SUBTYPE", XS_DBD__SQLite__Constants__const_function_flags_3030000, file, "");
        XSANY.any_i32 = SQLITE_SUBTYPE;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_function_flags_3030000", XS_DBD__SQLite__Constants__const_function_flags_3030000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAEX
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DIRECTONLY", XS_DBD__SQLite__Constants__const_function_flags_3030000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_SUBTYPE", XS_DBD__SQLite__Constants__const_function_flags_3030000_zero, file, "");
        XSANY.any_i32 = 2;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_function_flags_3030000_zero", XS_DBD__SQLite__Constants__const_function_flags_3030000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAEY
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_INNOCUOUS", XS_DBD__SQLite__Constants__const_function_flags_3031000, file, "");
        XSANY.any_i32 = SQLITE_INNOCUOUS;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_function_flags_3031000", XS_DBD__SQLite__Constants__const_function_flags_3031000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAEZ
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_INNOCUOUS", XS_DBD__SQLite__Constants__const_function_flags_3031000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_function_flags_3031000_zero", XS_DBD__SQLite__Constants__const_function_flags_3031000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAFA
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_RESULT_SUBTYPE", XS_DBD__SQLite__Constants__const_function_flags_3044001, file, "");
        XSANY.any_i32 = SQLITE_RESULT_SUBTYPE;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_function_flags_3044001", XS_DBD__SQLite__Constants__const_function_flags_3044001, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAFB
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_RESULT_SUBTYPE", XS_DBD__SQLite__Constants__const_function_flags_3044001_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_function_flags_3044001_zero", XS_DBD__SQLite__Constants__const_function_flags_3044001_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAFC
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_SELFORDER1", XS_DBD__SQLite__Constants__const_function_flags_3047000, file, "");
        XSANY.any_i32 = SQLITE_SELFORDER1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_function_flags_3047000", XS_DBD__SQLite__Constants__const_function_flags_3047000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAFD
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_SELFORDER1", XS_DBD__SQLite__Constants__const_function_flags_3047000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_function_flags_3047000_zero", XS_DBD__SQLite__Constants__const_function_flags_3047000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_BLOB", XS_DBD__SQLite__Constants__const_fundamental_datatypes, file, "");
        XSANY.any_i32 = SQLITE_BLOB;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_FLOAT", XS_DBD__SQLite__Constants__const_fundamental_datatypes, file, "");
        XSANY.any_i32 = SQLITE_FLOAT;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_INTEGER", XS_DBD__SQLite__Constants__const_fundamental_datatypes, file, "");
        XSANY.any_i32 = SQLITE_INTEGER;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_NULL", XS_DBD__SQLite__Constants__const_fundamental_datatypes, file, "");
        XSANY.any_i32 = SQLITE_NULL;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_TEXT", XS_DBD__SQLite__Constants__const_fundamental_datatypes, file, "");
        XSANY.any_i32 = SQLITE_TEXT;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_fundamental_datatypes", XS_DBD__SQLite__Constants__const_fundamental_datatypes, file, "");
        XSANY.any_i32 = 0;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_ABORT", XS_DBD__SQLite__Constants__const_result_codes, file, "");
        XSANY.any_i32 = SQLITE_ABORT;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_AUTH", XS_DBD__SQLite__Constants__const_result_codes, file, "");
        XSANY.any_i32 = SQLITE_AUTH;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_BUSY", XS_DBD__SQLite__Constants__const_result_codes, file, "");
        XSANY.any_i32 = SQLITE_BUSY;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CANTOPEN", XS_DBD__SQLite__Constants__const_result_codes, file, "");
        XSANY.any_i32 = SQLITE_CANTOPEN;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CONSTRAINT", XS_DBD__SQLite__Constants__const_result_codes, file, "");
        XSANY.any_i32 = SQLITE_CONSTRAINT;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_CORRUPT", XS_DBD__SQLite__Constants__const_result_codes, file, "");
        XSANY.any_i32 = SQLITE_CORRUPT;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_DONE", XS_DBD__SQLite__Constants__const_result_codes, file, "");
        XSANY.any_i32 = SQLITE_DONE;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_EMPTY", XS_DBD__SQLite__Constants__const_result_codes, file, "");
        XSANY.any_i32 = SQLITE_EMPTY;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_ERROR", XS_DBD__SQLite__Constants__const_result_codes, file, "");
        XSANY.any_i32 = SQLITE_ERROR;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_FORMAT", XS_DBD__SQLite__Constants__const_result_codes, file, "");
        XSANY.any_i32 = SQLITE_FORMAT;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_FULL", XS_DBD__SQLite__Constants__const_result_codes, file, "");
        XSANY.any_i32 = SQLITE_FULL;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_INTERNAL", XS_DBD__SQLite__Constants__const_result_codes, file, "");
        XSANY.any_i32 = SQLITE_INTERNAL;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_INTERRUPT", XS_DBD__SQLite__Constants__const_result_codes, file, "");
        XSANY.any_i32 = SQLITE_INTERRUPT;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_IOERR", XS_DBD__SQLite__Constants__const_result_codes, file, "");
        XSANY.any_i32 = SQLITE_IOERR;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_LOCKED", XS_DBD__SQLite__Constants__const_result_codes, file, "");
        XSANY.any_i32 = SQLITE_LOCKED;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_MISMATCH", XS_DBD__SQLite__Constants__const_result_codes, file, "");
        XSANY.any_i32 = SQLITE_MISMATCH;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_MISUSE", XS_DBD__SQLite__Constants__const_result_codes, file, "");
        XSANY.any_i32 = SQLITE_MISUSE;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_NOLFS", XS_DBD__SQLite__Constants__const_result_codes, file, "");
        XSANY.any_i32 = SQLITE_NOLFS;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_NOMEM", XS_DBD__SQLite__Constants__const_result_codes, file, "");
        XSANY.any_i32 = SQLITE_NOMEM;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_NOTADB", XS_DBD__SQLite__Constants__const_result_codes, file, "");
        XSANY.any_i32 = SQLITE_NOTADB;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_NOTFOUND", XS_DBD__SQLite__Constants__const_result_codes, file, "");
        XSANY.any_i32 = SQLITE_NOTFOUND;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_OK", XS_DBD__SQLite__Constants__const_result_codes, file, "");
        XSANY.any_i32 = SQLITE_OK;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_PERM", XS_DBD__SQLite__Constants__const_result_codes, file, "");
        XSANY.any_i32 = SQLITE_PERM;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_PROTOCOL", XS_DBD__SQLite__Constants__const_result_codes, file, "");
        XSANY.any_i32 = SQLITE_PROTOCOL;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_RANGE", XS_DBD__SQLite__Constants__const_result_codes, file, "");
        XSANY.any_i32 = SQLITE_RANGE;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_READONLY", XS_DBD__SQLite__Constants__const_result_codes, file, "");
        XSANY.any_i32 = SQLITE_READONLY;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_ROW", XS_DBD__SQLite__Constants__const_result_codes, file, "");
        XSANY.any_i32 = SQLITE_ROW;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_SCHEMA", XS_DBD__SQLite__Constants__const_result_codes, file, "");
        XSANY.any_i32 = SQLITE_SCHEMA;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_TOOBIG", XS_DBD__SQLite__Constants__const_result_codes, file, "");
        XSANY.any_i32 = SQLITE_TOOBIG;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_result_codes", XS_DBD__SQLite__Constants__const_result_codes, file, "");
        XSANY.any_i32 = 0;
#if XSubPPtmpAAFE
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_NOTICE", XS_DBD__SQLite__Constants__const_result_codes_3007017, file, "");
        XSANY.any_i32 = SQLITE_NOTICE;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_WARNING", XS_DBD__SQLite__Constants__const_result_codes_3007017, file, "");
        XSANY.any_i32 = SQLITE_WARNING;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_result_codes_3007017", XS_DBD__SQLite__Constants__const_result_codes_3007017, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAFF
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_NOTICE", XS_DBD__SQLite__Constants__const_result_codes_3007017_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_WARNING", XS_DBD__SQLite__Constants__const_result_codes_3007017_zero, file, "");
        XSANY.any_i32 = 2;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_result_codes_3007017_zero", XS_DBD__SQLite__Constants__const_result_codes_3007017_zero, file, "");
        XSANY.any_i32 = 0;
#endif
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_LIMIT_ATTACHED", XS_DBD__SQLite__Constants__const_run_time_limit_categories, file, "");
        XSANY.any_i32 = SQLITE_LIMIT_ATTACHED;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_LIMIT_COLUMN", XS_DBD__SQLite__Constants__const_run_time_limit_categories, file, "");
        XSANY.any_i32 = SQLITE_LIMIT_COLUMN;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_LIMIT_COMPOUND_SELECT", XS_DBD__SQLite__Constants__const_run_time_limit_categories, file, "");
        XSANY.any_i32 = SQLITE_LIMIT_COMPOUND_SELECT;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_LIMIT_EXPR_DEPTH", XS_DBD__SQLite__Constants__const_run_time_limit_categories, file, "");
        XSANY.any_i32 = SQLITE_LIMIT_EXPR_DEPTH;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_LIMIT_FUNCTION_ARG", XS_DBD__SQLite__Constants__const_run_time_limit_categories, file, "");
        XSANY.any_i32 = SQLITE_LIMIT_FUNCTION_ARG;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_LIMIT_LENGTH", XS_DBD__SQLite__Constants__const_run_time_limit_categories, file, "");
        XSANY.any_i32 = SQLITE_LIMIT_LENGTH;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_LIMIT_LIKE_PATTERN_LENGTH", XS_DBD__SQLite__Constants__const_run_time_limit_categories, file, "");
        XSANY.any_i32 = SQLITE_LIMIT_LIKE_PATTERN_LENGTH;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_LIMIT_SQL_LENGTH", XS_DBD__SQLite__Constants__const_run_time_limit_categories, file, "");
        XSANY.any_i32 = SQLITE_LIMIT_SQL_LENGTH;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_LIMIT_VARIABLE_NUMBER", XS_DBD__SQLite__Constants__const_run_time_limit_categories, file, "");
        XSANY.any_i32 = SQLITE_LIMIT_VARIABLE_NUMBER;
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_LIMIT_VDBE_OP", XS_DBD__SQLite__Constants__const_run_time_limit_categories, file, "");
        XSANY.any_i32 = SQLITE_LIMIT_VDBE_OP;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_run_time_limit_categories", XS_DBD__SQLite__Constants__const_run_time_limit_categories, file, "");
        XSANY.any_i32 = 0;
#if XSubPPtmpAAFG
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_LIMIT_TRIGGER_DEPTH", XS_DBD__SQLite__Constants__const_run_time_limit_categories_3006018, file, "");
        XSANY.any_i32 = SQLITE_LIMIT_TRIGGER_DEPTH;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_run_time_limit_categories_3006018", XS_DBD__SQLite__Constants__const_run_time_limit_categories_3006018, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAFH
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_LIMIT_TRIGGER_DEPTH", XS_DBD__SQLite__Constants__const_run_time_limit_categories_3006018_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_run_time_limit_categories_3006018_zero", XS_DBD__SQLite__Constants__const_run_time_limit_categories_3006018_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAFI
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_LIMIT_WORKER_THREADS", XS_DBD__SQLite__Constants__const_run_time_limit_categories_3008007, file, "");
        XSANY.any_i32 = SQLITE_LIMIT_WORKER_THREADS;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_run_time_limit_categories_3008007", XS_DBD__SQLite__Constants__const_run_time_limit_categories_3008007, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAFJ
        cv = newXSproto_portable("DBD::SQLite::Constants::SQLITE_LIMIT_WORKER_THREADS", XS_DBD__SQLite__Constants__const_run_time_limit_categories_3008007_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::Constants::_const_run_time_limit_categories_3008007_zero", XS_DBD__SQLite__Constants__const_run_time_limit_categories_3008007_zero, file, "");
        XSANY.any_i32 = 0;
#endif
        cv = newXSproto_portable("DBD::SQLite::ALTER_TABLE", XS_DBD__SQLite__const__authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_ALTER_TABLE;
        cv = newXSproto_portable("DBD::SQLite::ANALYZE", XS_DBD__SQLite__const__authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_ANALYZE;
        cv = newXSproto_portable("DBD::SQLite::ATTACH", XS_DBD__SQLite__const__authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_ATTACH;
        cv = newXSproto_portable("DBD::SQLite::COPY", XS_DBD__SQLite__const__authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_COPY;
        cv = newXSproto_portable("DBD::SQLite::CREATE_INDEX", XS_DBD__SQLite__const__authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_CREATE_INDEX;
        cv = newXSproto_portable("DBD::SQLite::CREATE_TABLE", XS_DBD__SQLite__const__authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_CREATE_TABLE;
        cv = newXSproto_portable("DBD::SQLite::CREATE_TEMP_INDEX", XS_DBD__SQLite__const__authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_CREATE_TEMP_INDEX;
        cv = newXSproto_portable("DBD::SQLite::CREATE_TEMP_TABLE", XS_DBD__SQLite__const__authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_CREATE_TEMP_TABLE;
        cv = newXSproto_portable("DBD::SQLite::CREATE_TEMP_TRIGGER", XS_DBD__SQLite__const__authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_CREATE_TEMP_TRIGGER;
        cv = newXSproto_portable("DBD::SQLite::CREATE_TEMP_VIEW", XS_DBD__SQLite__const__authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_CREATE_TEMP_VIEW;
        cv = newXSproto_portable("DBD::SQLite::CREATE_TRIGGER", XS_DBD__SQLite__const__authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_CREATE_TRIGGER;
        cv = newXSproto_portable("DBD::SQLite::CREATE_VIEW", XS_DBD__SQLite__const__authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_CREATE_VIEW;
        cv = newXSproto_portable("DBD::SQLite::CREATE_VTABLE", XS_DBD__SQLite__const__authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_CREATE_VTABLE;
        cv = newXSproto_portable("DBD::SQLite::DELETE", XS_DBD__SQLite__const__authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_DELETE;
        cv = newXSproto_portable("DBD::SQLite::DETACH", XS_DBD__SQLite__const__authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_DETACH;
        cv = newXSproto_portable("DBD::SQLite::DROP_INDEX", XS_DBD__SQLite__const__authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_DROP_INDEX;
        cv = newXSproto_portable("DBD::SQLite::DROP_TABLE", XS_DBD__SQLite__const__authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_DROP_TABLE;
        cv = newXSproto_portable("DBD::SQLite::DROP_TEMP_INDEX", XS_DBD__SQLite__const__authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_DROP_TEMP_INDEX;
        cv = newXSproto_portable("DBD::SQLite::DROP_TEMP_TABLE", XS_DBD__SQLite__const__authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_DROP_TEMP_TABLE;
        cv = newXSproto_portable("DBD::SQLite::DROP_TEMP_TRIGGER", XS_DBD__SQLite__const__authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_DROP_TEMP_TRIGGER;
        cv = newXSproto_portable("DBD::SQLite::DROP_TEMP_VIEW", XS_DBD__SQLite__const__authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_DROP_TEMP_VIEW;
        cv = newXSproto_portable("DBD::SQLite::DROP_TRIGGER", XS_DBD__SQLite__const__authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_DROP_TRIGGER;
        cv = newXSproto_portable("DBD::SQLite::DROP_VIEW", XS_DBD__SQLite__const__authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_DROP_VIEW;
        cv = newXSproto_portable("DBD::SQLite::DROP_VTABLE", XS_DBD__SQLite__const__authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_DROP_VTABLE;
        cv = newXSproto_portable("DBD::SQLite::FUNCTION", XS_DBD__SQLite__const__authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_FUNCTION;
        cv = newXSproto_portable("DBD::SQLite::INSERT", XS_DBD__SQLite__const__authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_INSERT;
        cv = newXSproto_portable("DBD::SQLite::PRAGMA", XS_DBD__SQLite__const__authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_PRAGMA;
        cv = newXSproto_portable("DBD::SQLite::READ", XS_DBD__SQLite__const__authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_READ;
        cv = newXSproto_portable("DBD::SQLite::REINDEX", XS_DBD__SQLite__const__authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_REINDEX;
        cv = newXSproto_portable("DBD::SQLite::SELECT", XS_DBD__SQLite__const__authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_SELECT;
        cv = newXSproto_portable("DBD::SQLite::TRANSACTION", XS_DBD__SQLite__const__authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_TRANSACTION;
        cv = newXSproto_portable("DBD::SQLite::UPDATE", XS_DBD__SQLite__const__authorizer_action_codes, file, "");
        XSANY.any_i32 = SQLITE_UPDATE;
        cv = newXSproto_portable("DBD::SQLite::_const__authorizer_action_codes", XS_DBD__SQLite__const__authorizer_action_codes, file, "");
        XSANY.any_i32 = 0;
#if XSubPPtmpAAFK
        cv = newXSproto_portable("DBD::SQLite::SAVEPOINT", XS_DBD__SQLite__const__authorizer_action_codes_3006008, file, "");
        XSANY.any_i32 = SQLITE_SAVEPOINT;
        cv = newXSproto_portable("DBD::SQLite::_const__authorizer_action_codes_3006008", XS_DBD__SQLite__const__authorizer_action_codes_3006008, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAFL
        cv = newXSproto_portable("DBD::SQLite::SAVEPOINT", XS_DBD__SQLite__const__authorizer_action_codes_3006008_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::_const__authorizer_action_codes_3006008_zero", XS_DBD__SQLite__const__authorizer_action_codes_3006008_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAFM
        cv = newXSproto_portable("DBD::SQLite::RECURSIVE", XS_DBD__SQLite__const__authorizer_action_codes_3008003, file, "");
        XSANY.any_i32 = SQLITE_RECURSIVE;
        cv = newXSproto_portable("DBD::SQLite::_const__authorizer_action_codes_3008003", XS_DBD__SQLite__const__authorizer_action_codes_3008003, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAFN
        cv = newXSproto_portable("DBD::SQLite::RECURSIVE", XS_DBD__SQLite__const__authorizer_action_codes_3008003_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::_const__authorizer_action_codes_3008003_zero", XS_DBD__SQLite__const__authorizer_action_codes_3008003_zero, file, "");
        XSANY.any_i32 = 0;
#endif
        cv = newXSproto_portable("DBD::SQLite::DENY", XS_DBD__SQLite__const__authorizer_return_codes, file, "");
        XSANY.any_i32 = SQLITE_DENY;
        cv = newXSproto_portable("DBD::SQLite::IGNORE", XS_DBD__SQLite__const__authorizer_return_codes, file, "");
        XSANY.any_i32 = SQLITE_IGNORE;
        cv = newXSproto_portable("DBD::SQLite::OK", XS_DBD__SQLite__const__authorizer_return_codes, file, "");
        XSANY.any_i32 = SQLITE_OK;
        cv = newXSproto_portable("DBD::SQLite::_const__authorizer_return_codes", XS_DBD__SQLite__const__authorizer_return_codes, file, "");
        XSANY.any_i32 = 0;
        cv = newXSproto_portable("DBD::SQLite::OPEN_CREATE", XS_DBD__SQLite__const__flags_for_file_open_operations, file, "");
        XSANY.any_i32 = SQLITE_OPEN_CREATE;
        cv = newXSproto_portable("DBD::SQLite::OPEN_NOMUTEX", XS_DBD__SQLite__const__flags_for_file_open_operations, file, "");
        XSANY.any_i32 = SQLITE_OPEN_NOMUTEX;
        cv = newXSproto_portable("DBD::SQLite::OPEN_READONLY", XS_DBD__SQLite__const__flags_for_file_open_operations, file, "");
        XSANY.any_i32 = SQLITE_OPEN_READONLY;
        cv = newXSproto_portable("DBD::SQLite::OPEN_READWRITE", XS_DBD__SQLite__const__flags_for_file_open_operations, file, "");
        XSANY.any_i32 = SQLITE_OPEN_READWRITE;
        cv = newXSproto_portable("DBD::SQLite::_const__flags_for_file_open_operations", XS_DBD__SQLite__const__flags_for_file_open_operations, file, "");
        XSANY.any_i32 = 0;
#if XSubPPtmpAAFO
        cv = newXSproto_portable("DBD::SQLite::OPEN_FULLMUTEX", XS_DBD__SQLite__const__flags_for_file_open_operations_3006002, file, "");
        XSANY.any_i32 = SQLITE_OPEN_FULLMUTEX;
        cv = newXSproto_portable("DBD::SQLite::_const__flags_for_file_open_operations_3006002", XS_DBD__SQLite__const__flags_for_file_open_operations_3006002, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAFP
        cv = newXSproto_portable("DBD::SQLite::OPEN_FULLMUTEX", XS_DBD__SQLite__const__flags_for_file_open_operations_3006002_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::_const__flags_for_file_open_operations_3006002_zero", XS_DBD__SQLite__const__flags_for_file_open_operations_3006002_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAFQ
        cv = newXSproto_portable("DBD::SQLite::OPEN_PRIVATECACHE", XS_DBD__SQLite__const__flags_for_file_open_operations_3006018, file, "");
        XSANY.any_i32 = SQLITE_OPEN_PRIVATECACHE;
        cv = newXSproto_portable("DBD::SQLite::OPEN_SHAREDCACHE", XS_DBD__SQLite__const__flags_for_file_open_operations_3006018, file, "");
        XSANY.any_i32 = SQLITE_OPEN_SHAREDCACHE;
        cv = newXSproto_portable("DBD::SQLite::_const__flags_for_file_open_operations_3006018", XS_DBD__SQLite__const__flags_for_file_open_operations_3006018, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAFR
        cv = newXSproto_portable("DBD::SQLite::OPEN_PRIVATECACHE", XS_DBD__SQLite__const__flags_for_file_open_operations_3006018_zero, file, "");
        XSANY.any_i32 = 2;
        cv = newXSproto_portable("DBD::SQLite::OPEN_SHAREDCACHE", XS_DBD__SQLite__const__flags_for_file_open_operations_3006018_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::_const__flags_for_file_open_operations_3006018_zero", XS_DBD__SQLite__const__flags_for_file_open_operations_3006018_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAFS
        cv = newXSproto_portable("DBD::SQLite::OPEN_URI", XS_DBD__SQLite__const__flags_for_file_open_operations_3007007, file, "");
        XSANY.any_i32 = SQLITE_OPEN_URI;
        cv = newXSproto_portable("DBD::SQLite::_const__flags_for_file_open_operations_3007007", XS_DBD__SQLite__const__flags_for_file_open_operations_3007007, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAFT
        cv = newXSproto_portable("DBD::SQLite::OPEN_URI", XS_DBD__SQLite__const__flags_for_file_open_operations_3007007_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::_const__flags_for_file_open_operations_3007007_zero", XS_DBD__SQLite__const__flags_for_file_open_operations_3007007_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAFU
        cv = newXSproto_portable("DBD::SQLite::OPEN_MEMORY", XS_DBD__SQLite__const__flags_for_file_open_operations_3007013, file, "");
        XSANY.any_i32 = SQLITE_OPEN_MEMORY;
        cv = newXSproto_portable("DBD::SQLite::_const__flags_for_file_open_operations_3007013", XS_DBD__SQLite__const__flags_for_file_open_operations_3007013, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAFV
        cv = newXSproto_portable("DBD::SQLite::OPEN_MEMORY", XS_DBD__SQLite__const__flags_for_file_open_operations_3007013_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::_const__flags_for_file_open_operations_3007013_zero", XS_DBD__SQLite__const__flags_for_file_open_operations_3007013_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAFW
        cv = newXSproto_portable("DBD::SQLite::OPEN_NOFOLLOW", XS_DBD__SQLite__const__flags_for_file_open_operations_3031000, file, "");
        XSANY.any_i32 = SQLITE_OPEN_NOFOLLOW;
        cv = newXSproto_portable("DBD::SQLite::_const__flags_for_file_open_operations_3031000", XS_DBD__SQLite__const__flags_for_file_open_operations_3031000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAFX
        cv = newXSproto_portable("DBD::SQLite::OPEN_NOFOLLOW", XS_DBD__SQLite__const__flags_for_file_open_operations_3031000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::_const__flags_for_file_open_operations_3031000_zero", XS_DBD__SQLite__const__flags_for_file_open_operations_3031000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAFY
        cv = newXSproto_portable("DBD::SQLite::OPEN_SUPER_JOURNAL", XS_DBD__SQLite__const__flags_for_file_open_operations_3033000, file, "");
        XSANY.any_i32 = SQLITE_OPEN_SUPER_JOURNAL;
        cv = newXSproto_portable("DBD::SQLite::_const__flags_for_file_open_operations_3033000", XS_DBD__SQLite__const__flags_for_file_open_operations_3033000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAFZ
        cv = newXSproto_portable("DBD::SQLite::OPEN_SUPER_JOURNAL", XS_DBD__SQLite__const__flags_for_file_open_operations_3033000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::_const__flags_for_file_open_operations_3033000_zero", XS_DBD__SQLite__const__flags_for_file_open_operations_3033000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAGA
        cv = newXSproto_portable("DBD::SQLite::OPEN_EXRESCODE", XS_DBD__SQLite__const__flags_for_file_open_operations_3037000, file, "");
        XSANY.any_i32 = SQLITE_OPEN_EXRESCODE;
        cv = newXSproto_portable("DBD::SQLite::_const__flags_for_file_open_operations_3037000", XS_DBD__SQLite__const__flags_for_file_open_operations_3037000, file, "");
        XSANY.any_i32 = 0;
#endif
#if XSubPPtmpAAGB
        cv = newXSproto_portable("DBD::SQLite::OPEN_EXRESCODE", XS_DBD__SQLite__const__flags_for_file_open_operations_3037000_zero, file, "");
        XSANY.any_i32 = 1;
        cv = newXSproto_portable("DBD::SQLite::_const__flags_for_file_open_operations_3037000_zero", XS_DBD__SQLite__const__flags_for_file_open_operations_3037000_zero, file, "");
        XSANY.any_i32 = 0;
#endif
    }

    /* Initialisation Section */

#line 12 "SQLite.xs"
    init_cxt();
    sv_setpv(get_sv("DBD::SQLite::sqlite_version",        TRUE|GV_ADDMULTI), SQLITE_VERSION);
    sv_setiv(get_sv("DBD::SQLite::sqlite_version_number", TRUE|GV_ADDMULTI), SQLITE_VERSION_NUMBER);

#if XSubPPtmpAAAA
#endif
#if XSubPPtmpAAAB
#endif
#line 40 "./SQLite.xsi"
    PERL_UNUSED_VAR(items);
    DBISTATE_INIT;
    /* XXX this interface will change: */
    DBI_IMP_SIZE("DBD::SQLite::dr::imp_data_size", sizeof(imp_drh_t));
    DBI_IMP_SIZE("DBD::SQLite::db::imp_data_size", sizeof(imp_dbh_t));
    DBI_IMP_SIZE("DBD::SQLite::st::imp_data_size", sizeof(imp_sth_t));
    dbd_init(DBIS);

#if XSubPPtmpAAAC
#endif
#if XSubPPtmpAAAD
#endif
#if XSubPPtmpAAAE
#endif
#if XSubPPtmpAAAF
#endif
#if XSubPPtmpAAAG
#endif
#if XSubPPtmpAAAH
#endif
#if XSubPPtmpAAAI
#endif
#if XSubPPtmpAAAJ
#endif
#if XSubPPtmpAAAK
#endif
#if XSubPPtmpAAAL
#endif
#line 9 "./constants.inc"
    newCONSTSUB( gv_stashpv("DBD::SQLite::Constants", FALSE), "DBD_SQLITE_STRING_MODE_PV", newSVuv(DBD_SQLITE_STRING_MODE_PV) );
    newCONSTSUB( gv_stashpv("DBD::SQLite::Constants", FALSE), "DBD_SQLITE_STRING_MODE_BYTES", newSVuv(DBD_SQLITE_STRING_MODE_BYTES) );
    newCONSTSUB( gv_stashpv("DBD::SQLite::Constants", FALSE), "DBD_SQLITE_STRING_MODE_UNICODE_NAIVE", newSVuv(DBD_SQLITE_STRING_MODE_UNICODE_NAIVE) );
    newCONSTSUB( gv_stashpv("DBD::SQLite::Constants", FALSE), "DBD_SQLITE_STRING_MODE_UNICODE_FALLBACK", newSVuv(DBD_SQLITE_STRING_MODE_UNICODE_FALLBACK) );
    newCONSTSUB( gv_stashpv("DBD::SQLite::Constants", FALSE), "DBD_SQLITE_STRING_MODE_UNICODE_STRICT", newSVuv(DBD_SQLITE_STRING_MODE_UNICODE_STRICT) );

#if XSubPPtmpAAAM
#endif
#if XSubPPtmpAAAN
#endif
#if XSubPPtmpAAAO
#endif
#if XSubPPtmpAAAP
#endif
#if XSubPPtmpAAAQ
#endif
#if XSubPPtmpAAAR
#endif
#if XSubPPtmpAAAS
#endif
#if XSubPPtmpAAAT
#endif
#if XSubPPtmpAAAU
#endif
#if XSubPPtmpAAAV
#endif
#if XSubPPtmpAAAW
#endif
#if XSubPPtmpAAAX
#endif
#if XSubPPtmpAAAY
#endif
#if XSubPPtmpAAAZ
#endif
#if XSubPPtmpAABA
#endif
#if XSubPPtmpAABB
#endif
#if XSubPPtmpAABC
#endif
#if XSubPPtmpAABD
#endif
#if XSubPPtmpAABE
#endif
#if XSubPPtmpAABF
#endif
#if XSubPPtmpAABG
#endif
#if XSubPPtmpAABH
#endif
#if XSubPPtmpAABI
#endif
#if XSubPPtmpAABJ
#endif
#if XSubPPtmpAABK
#endif
#if XSubPPtmpAABL
#endif
#if XSubPPtmpAABM
#endif
#if XSubPPtmpAABN
#endif
#if XSubPPtmpAABO
#endif
#if XSubPPtmpAABP
#endif
#if XSubPPtmpAABQ
#endif
#if XSubPPtmpAABR
#endif
#if XSubPPtmpAABS
#endif
#if XSubPPtmpAABT
#endif
#if XSubPPtmpAABU
#endif
#if XSubPPtmpAABV
#endif
#if XSubPPtmpAABW
#endif
#if XSubPPtmpAABX
#endif
#if XSubPPtmpAABY
#endif
#if XSubPPtmpAABZ
#endif
#if XSubPPtmpAACA
#endif
#if XSubPPtmpAACB
#endif
#if XSubPPtmpAACC
#endif
#if XSubPPtmpAACD
#endif
#if XSubPPtmpAACE
#endif
#if XSubPPtmpAACF
#endif
#if XSubPPtmpAACG
#endif
#if XSubPPtmpAACH
#endif
#if XSubPPtmpAACI
#endif
#if XSubPPtmpAACJ
#endif
#if XSubPPtmpAACK
#endif
#if XSubPPtmpAACL
#endif
#if XSubPPtmpAACM
#endif
#if XSubPPtmpAACN
#endif
#if XSubPPtmpAACO
#endif
#if XSubPPtmpAACP
#endif
#if XSubPPtmpAACQ
#endif
#if XSubPPtmpAACR
#endif
#if XSubPPtmpAACS
#endif
#if XSubPPtmpAACT
#endif
#if XSubPPtmpAACU
#endif
#if XSubPPtmpAACV
#endif
#if XSubPPtmpAACW
#endif
#if XSubPPtmpAACX
#endif
#if XSubPPtmpAACY
#endif
#if XSubPPtmpAACZ
#endif
#if XSubPPtmpAADA
#endif
#if XSubPPtmpAADB
#endif
#if XSubPPtmpAADC
#endif
#if XSubPPtmpAADD
#endif
#if XSubPPtmpAADE
#endif
#if XSubPPtmpAADF
#endif
#if XSubPPtmpAADG
#endif
#if XSubPPtmpAADH
#endif
#if XSubPPtmpAADI
#endif
#if XSubPPtmpAADJ
#endif
#if XSubPPtmpAADK
#endif
#if XSubPPtmpAADL
#endif
#if XSubPPtmpAADM
#endif
#if XSubPPtmpAADN
#endif
#if XSubPPtmpAADO
#endif
#if XSubPPtmpAADP
#endif
#if XSubPPtmpAADQ
#endif
#if XSubPPtmpAADR
#endif
#if XSubPPtmpAADS
#endif
#if XSubPPtmpAADT
#endif
#if XSubPPtmpAADU
#endif
#if XSubPPtmpAADV
#endif
#if XSubPPtmpAADW
#endif
#if XSubPPtmpAADX
#endif
#if XSubPPtmpAADY
#endif
#if XSubPPtmpAADZ
#endif
#if XSubPPtmpAAEA
#endif
#if XSubPPtmpAAEB
#endif
#if XSubPPtmpAAEC
#endif
#if XSubPPtmpAAED
#endif
#if XSubPPtmpAAEE
#endif
#if XSubPPtmpAAEF
#endif
#if XSubPPtmpAAEG
#endif
#if XSubPPtmpAAEH
#endif
#if XSubPPtmpAAEI
#endif
#if XSubPPtmpAAEJ
#endif
#if XSubPPtmpAAEK
#endif
#if XSubPPtmpAAEL
#endif
#if XSubPPtmpAAEM
#endif
#if XSubPPtmpAAEN
#endif
#if XSubPPtmpAAEO
#endif
#if XSubPPtmpAAEP
#endif
#if XSubPPtmpAAEQ
#endif
#if XSubPPtmpAAER
#endif
#if XSubPPtmpAAES
#endif
#if XSubPPtmpAAET
#endif
#if XSubPPtmpAAEU
#endif
#if XSubPPtmpAAEV
#endif
#if XSubPPtmpAAEW
#endif
#if XSubPPtmpAAEX
#endif
#if XSubPPtmpAAEY
#endif
#if XSubPPtmpAAEZ
#endif
#if XSubPPtmpAAFA
#endif
#if XSubPPtmpAAFB
#endif
#if XSubPPtmpAAFC
#endif
#if XSubPPtmpAAFD
#endif
#if XSubPPtmpAAFE
#endif
#if XSubPPtmpAAFF
#endif
#if XSubPPtmpAAFG
#endif
#if XSubPPtmpAAFH
#endif
#if XSubPPtmpAAFI
#endif
#if XSubPPtmpAAFJ
#endif
#if XSubPPtmpAAFK
#endif
#if XSubPPtmpAAFL
#endif
#if XSubPPtmpAAFM
#endif
#if XSubPPtmpAAFN
#endif
#if XSubPPtmpAAFO
#endif
#if XSubPPtmpAAFP
#endif
#if XSubPPtmpAAFQ
#endif
#if XSubPPtmpAAFR
#endif
#if XSubPPtmpAAFS
#endif
#if XSubPPtmpAAFT
#endif
#if XSubPPtmpAAFU
#endif
#if XSubPPtmpAAFV
#endif
#if XSubPPtmpAAFW
#endif
#if XSubPPtmpAAFX
#endif
#if XSubPPtmpAAFY
#endif
#if XSubPPtmpAAFZ
#endif
#if XSubPPtmpAAGA
#endif
#if XSubPPtmpAAGB
#endif
#line 8080 "SQLite.c"

    /* End of Initialisation Section */

#if PERL_VERSION_LE(5, 21, 5)
#  if PERL_VERSION_GE(5, 9, 0)
    if (PL_unitcheckav)
        call_list(PL_scopestack_ix, PL_unitcheckav);
#  endif
    XSRETURN_YES;
#else
    Perl_xs_boot_epilog(aTHX_ ax);
#endif
}

#ifdef __cplusplus
}
#endif
